@@ -59,6 +59,9 @@
 #  include <dune/uggrid/parallel/ddd/dddtypes.hh>
 #endif
 
+#include <dune/common/fvector.hh>
+
+#include <dune/uggrid/low/dimension.h>
 #include <dune/uggrid/low/heaps.h>
 #include <dune/uggrid/low/namespace.h>
 #include <dune/uggrid/low/ugenv.h>
@@ -86,7 +89,6 @@ typedef INT (*UserProcPtr)(DOUBLE *, DOUBLE *);
 #define BVPD_MIDPOINT(d)     ((d)->midpoint)
 #define BVPD_RADIUS(d)       ((d)->radius)
 #define BVPD_CONVEX(d)       ((d)->convex)
-#define BVPD_NSUBDOM(d)      ((d)->nSubDomains)
 #define BVPD_CONFIG(d)       ((d)->ConfigProc)
 #define BVPD_NCOEFFF(d)      ((d)->numOfCoeffFct)
 #define BVPD_NUSERF(d)       ((d)->numOfUserFct)
@@ -111,12 +113,6 @@ struct BVP_Descriptor
   char name[NS_PREFIX NAMELEN];
   /*@}*/
 
-  /** @name Domain part */
-  /*@{*/
-  /** \brief Number of subdomains, exterior not counted                */
-  INT nSubDomains;
-  /*@}*/
-
   /** @name Problem part */
   /*@{*/
   /** \brief Configuration function              */
@@ -151,9 +147,6 @@ struct mesh
   /** \brief Positions of inner nodes            */
   DOUBLE **Position;
 
-  /** \brief Number of subdomains                   */
-  INT nSubDomains;
-
   /** \brief Number of boundary sides per subdomain */
   INT *nSides;
 
@@ -393,24 +386,7 @@ INT         BNDP_SaveInsertedBndP (BNDP *theBndP, char *data, INT max_data_size)
  *   <li> 1 if error. </li>
  * </ul> */
 /****************************************************************************/
-INT         BNDP_Global           (BNDP *theBndP, DOUBLE *global);
-
-/****************************************************************************/
-/** \brief Change global coordinates of free boundary point
- *
- * @param aBndP - BNDP structure
- * @param global - new global coordinates
-
-   This function sets global coordinates of a free BNDP. The local coordinates
-   will be kept fixed which implies that the topology of the boundary triangulation
-   must not be changed!
-
- * @return <ul>
- *   <li> 0 if ok </li>
- *   <li> 1 if error. </li>
- * </ul> */
-/****************************************************************************/
-INT         BNDP_Move                         (BNDP *aBndP, const DOUBLE global[]);
+INT         BNDP_Global           (const BNDP *theBndP, Dune::FieldVector<DOUBLE,DIM>& global);
 
 /****************************************************************************/
 /** \brief Sets descriptor for BNDP
@@ -523,22 +499,6 @@ INT         BNDP_SaveBndP_Ext     (BNDP *theBndP);
 BNDP       *BNDP_LoadBndP         (BVP *theBVP, NS_PREFIX HEAP *Heap);
 BNDP       *BNDP_LoadBndP_Ext     (void);
 
-/****************************************************************************/
-/** \brief Gets global coordinates of local position on BNDS
- *
- * @param theBndS  - BNDS structure
- * @param local  - local coordinate on BNDS
- * @param global - global coordinate
-
-   This function gets global coordinates of local position on BNDS
-
- * @return <ul>
- *   <li> 0 if ok </li>
- *   <li> 1 if error. </li>
- * </ul> */
-/****************************************************************************/
-INT         BNDS_Global           (BNDS *theBndS, DOUBLE *local, DOUBLE *global);
-
 /****************************************************************************/
 /** \brief Sets descriptor for BNDS
  *
@@ -570,7 +530,7 @@ INT         BNDS_BndSDesc         (BNDS *theBndS, INT *id, INT *nbid);
  *   <li> 1 if error. </li>
  * </ul> */
 /****************************************************************************/
-BNDP*       BNDS_CreateBndP       (NS_PREFIX HEAP *Heap, BNDS *theBndS, DOUBLE *local);
+BNDP*       BNDS_CreateBndP       (NS_PREFIX HEAP *Heap, BNDS *theBndS, const FieldVector<DOUBLE,DIM_OF_BND>& local);
 
 /****************************************************************************/
 /** \brief Dispose BNDS
