@@ -54,6 +54,8 @@
 /* set needed in BVP_Init */
 #include <set>
 
+#include <dune/common/fvector.hh>
+
 /* low modules */
 #include <dune/uggrid/low/architecture.h>
 #include <dune/uggrid/low/bio.h>
@@ -117,21 +119,44 @@ static INT theProblemDirID;     /*!< env type for Problem dir
 static INT theBdryCondVarID;    /*!<  env type for Problem vars                 */
 
 static INT theDomainDirID;      /*!<  env type for Domain dir                           */
-static INT theBdrySegVarID;     /*!<  env type for bdry segment vars            */
-static INT theLinSegVarID;      /*!<  env type for linear segment vars              */
 
 static INT theBVPDirID;         /*!<  env type for BVP dir                                      */
 
 static STD_BVP *currBVP;
 
+
 /****************************************************************************/
-/*                                                                          */
-/* forward declarations of functions used before they are defined	    */
-/*                                                                          */
+/* Methods for the class 'boundary_segment'                                 */
 /****************************************************************************/
 
-static INT BndPointGlobal (const BNDP * aBndP, DOUBLE * global);
-static INT PatchGlobal (const PATCH * p, DOUBLE * lambda, DOUBLE * global);
+boundary_segment::boundary_segment(INT idA,
+                                   const INT* pointsA,
+                                   BndSegFuncPtr bndSegFuncA,
+                                   void *dataA)
+: id(idA), BndSegFunc(bndSegFuncA), data(dataA)
+{
+  for (INT i = 0; i < CORNERS_OF_BND_SEG; i++)
+    points[i] = pointsA[i];
+}
+
+
+/****************************************************************************/
+/* Methods for the class 'linear_segment'                                   */
+/****************************************************************************/
+
+linear_segment::linear_segment(INT idA,
+                               INT nA,
+                               const INT * point,
+                               const std::array<FieldVector<DOUBLE,DIM>, CORNERS_OF_BND_SEG>& xA)
+: id(idA), n(nA), x(xA)
+{
+  if (n > CORNERS_OF_BND_SEG)
+    std::terminate();
+
+  for (int i = 0; i < n; i++)
+    points[i] = point[i];
+}
+
 
 /****************************************************************************/
 /** \brief Create a new DOMAIN data structure
@@ -153,7 +178,7 @@ static INT PatchGlobal (const PATCH * p, DOUBLE * lambda, DOUBLE * global);
  */
 /****************************************************************************/
 
-void *NS_DIM_PREFIX
+domain *NS_DIM_PREFIX
 CreateDomain (const char *name, INT segments,
               INT corners)
 {
@@ -224,180 +249,11 @@ RemoveDomain (const char *name)
   }
 }
 
-/****************************************************************************/
-/** \brief Create a new BOUNDARY_SEGMENT
- *
- * @param  name - name of the boundary segment
- * @param  left - id of left subdomain
- * @param  right - id of right subdomain
- * @param  id - id of this boundary segment
- * @param  point - the endpoints of the boundary segment
- * @param  alpha - list where the parameter interval begins
- * @param  beta - list where the parameter interval ends
- * @param  BndSegFunc - function mapping parameters
- * @param  data - user defined space
- *
- * This function allocates and initializes a new BOUNDARY_SEGMENT for the previously
- * allocated DOMAIN structure.
- *
- * @return <ul>
- *   <li>     Pointer to a BOUNDARY_SEGMENT </li>
- *   <li>     NULL if out of memory.     </li>
- * </ul>
- */
-/****************************************************************************/
-
-void *NS_DIM_PREFIX
-CreateBoundarySegment (const char *name,
-                       INT left, INT right, INT id,
-                       const INT * point, const DOUBLE * alpha, const DOUBLE * beta,
-                       BndSegFuncPtr BndSegFunc, void *data)
-{
-  BOUNDARY_SEGMENT *newSegment;
-  INT i;
-
-  /* allocate the boundary segment */
-  newSegment =
-    (BOUNDARY_SEGMENT *) MakeEnvItem (name, theBdrySegVarID,
-                                      sizeof (BOUNDARY_SEGMENT));
-  if (newSegment == NULL)
-    return (NULL);
-
-  /* fill in data */
-  newSegment->left = left;
-  newSegment->right = right;
-  newSegment->id = id;
-  for (i = 0; i < CORNERS_OF_BND_SEG; i++)
-    newSegment->points[i] = point[i];
-  for (i = 0; i < DIM_OF_BND; i++)
-  {
-    newSegment->alpha[i] = alpha[i];
-    newSegment->beta[i] = beta[i];
-  }
-  newSegment->BndSegFunc = BndSegFunc;
-  newSegment->data = data;
-
-  return (newSegment);
-}
-
-/****************************************************************************/
-/** \brief Get next boundary segment of a domain
- *
- * @param  theBSeg - pointer to a boundary segment
- *
- * This function gets the next boundary segment of a domain.
- *
- * @return <ul>
- *   <li>     pointer to next BOUNDARY_SEGMENT </li>
- *   <li>     NULL if no more found.  </li>
- * </ul>
- */
-/****************************************************************************/
-
-static BOUNDARY_SEGMENT *
-GetNextBoundarySegment (BOUNDARY_SEGMENT * theBSeg)
-{
-  ENVITEM *theItem;
-
-  theItem = (ENVITEM *) theBSeg;
-
-  do
-    theItem = NEXT_ENVITEM (theItem);
-  while ((theItem != NULL) && (ENVITEM_TYPE (theItem) != theBdrySegVarID));
-
-  return ((BOUNDARY_SEGMENT *) theItem);
-}
-
-/****************************************************************************/
-/** \brief Get first boundary segment of a domain
- *
- * @param  theDomain - pointer to the domain structure
- *
- * This function returns the first boundary segment of a domain.
- *
- * @return <ul>
- *   <li>     pointer to a BOUNDARY_SEGMENT </li>
- *   <li>     NULL if not found or error.  </li>
- * </ul>
- */
-/****************************************************************************/
-
-static BOUNDARY_SEGMENT *
-GetFirstBoundarySegment (DOMAIN * theDomain)
-{
-  ENVITEM *theItem;
-
-  theItem = ENVITEM_DOWN (theDomain);
-
-  if (ENVITEM_TYPE (theItem) == theBdrySegVarID)
-    return ((BOUNDARY_SEGMENT *) theItem);
-  else
-    return (GetNextBoundarySegment ((BOUNDARY_SEGMENT *) theItem));
-}
-
-/****************************************************************************/
-/** \brief  Create a new LINEAR_SEGMENT
- *
- * @param  name - name of the boundary segment
- * @param  left - id of left subdomain
- * @param  right - id of right subdomain
- * @param  id - id of this boundary segment
- * @param  n - number of corners
- * @param  point - the endpoints of the boundary segment
- * @param  x - coordinates
- *
- * This function allocates and initializes a new LINEAR_SEGMENT
- * for the previously allocated DOMAIN structure.
- *
- * @return <ul>
- *   <li>     Pointer to a LINEAR_SEGMENT </li>
- *   <li>     NULL if out of memory. </li>
- * </ul>
- */
-/****************************************************************************/
-
-void *NS_DIM_PREFIX
-CreateLinearSegment (const char *name,
-                     INT left, INT right, INT id,
-                     INT n, const INT * point,
-                     DOUBLE x[CORNERS_OF_BND_SEG][DIM])
-{
-  LINEAR_SEGMENT *newSegment;
-  INT i, k;
-
-  if (n > CORNERS_OF_BND_SEG)
-    return (NULL);
-
-  /* allocate the boundary segment */
-  newSegment = (LINEAR_SEGMENT *)
-               MakeEnvItem (name, theLinSegVarID, sizeof (LINEAR_SEGMENT));
-
-  if (newSegment == NULL)
-    return (NULL);
-
-  /* fill in data */
-  newSegment->left = left;
-  newSegment->right = right;
-  newSegment->id = id;
-  newSegment->n = n;
-  for (i = 0; i < n; i++)
-  {
-    newSegment->points[i] = point[i];
-    for (k = 0; k < DIM; k++)
-      newSegment->x[i][k] = x[i][k];
-  }
-
-  return (newSegment);
-}
-
 UINT NS_DIM_PREFIX GetBoundarySegmentId(BNDS* boundarySegment)
 {
-  BND_PS *ps;
-  PATCH *patch;
-
-  ps = (BND_PS *) boundarySegment;
-  patch = currBVP->patches[ps->patch_id];
-  if (patch == NULL) {
+  const BND_PS *ps = (BND_PS*)boundarySegment;
+  const PATCH *patch = currBVP->patches[ps->patch_id];
+  if (patch == nullptr) {
     PrintErrorMessageF ('E', "GetBoundarySegmentId", "invalid argument");
     return 0;
   }
@@ -407,34 +263,6 @@ UINT NS_DIM_PREFIX GetBoundarySegmentId(BNDS* boundarySegment)
   return PATCH_ID(patch) - currBVP->sideoffset;
 }
 
-
-static LINEAR_SEGMENT *
-GetNextLinearSegment (LINEAR_SEGMENT * theBSeg)
-{
-  ENVITEM *theItem;
-
-  theItem = (ENVITEM *) theBSeg;
-
-  do
-    theItem = NEXT_ENVITEM (theItem);
-  while ((theItem != NULL) && (ENVITEM_TYPE (theItem) != theLinSegVarID));
-
-  return ((LINEAR_SEGMENT *) theItem);
-}
-
-static LINEAR_SEGMENT *
-GetFirstLinearSegment (DOMAIN * theDomain)
-{
-  ENVITEM *theItem;
-
-  theItem = ENVITEM_DOWN (theDomain);
-
-  if (ENVITEM_TYPE (theItem) == theLinSegVarID)
-    return ((LINEAR_SEGMENT *) theItem);
-  else
-    return (GetNextLinearSegment ((LINEAR_SEGMENT *) theItem));
-}
-
 /* configuring a domain */
 static INT STD_BVP_Configure(INT argc, char **argv)
 {
@@ -506,7 +334,7 @@ CreateBoundaryValueProblem (const char *BVPName, BndCondProcPtr theBndCond,
 }
 
 static INT
-GetNumberOfPatches (PATCH * p)
+GetNumberOfPatches (const PATCH * p)
 {
   switch (PATCH_TYPE (p))
   {
@@ -525,7 +353,7 @@ GetNumberOfPatches (PATCH * p)
 }
 
 static INT
-GetPatchId (PATCH * p, INT i)
+GetPatchId (const PATCH * p, INT i)
 {
   switch (PATCH_TYPE (p))
   {
@@ -645,16 +473,6 @@ CreateBndPOnPoint (HEAP * Heap, PATCH * p)
       }
     }
   }
-  if (!PATCH_IS_FIXED (p))
-  {
-    /* store global coordinates */
-    BND_DATA (ps) = GetFreelistMemory (Heap, DIM * sizeof (DOUBLE));
-    if (BND_DATA (ps) == NULL)
-      REP_ERR_RETURN (NULL);
-
-    if (BndPointGlobal ((BNDP *) ps, (DOUBLE *) BND_DATA (ps)))
-      REP_ERR_RETURN (NULL);
-  }
   return ((BNDP *) ps);
 }
 
@@ -683,11 +501,10 @@ CreateCornerPoints (HEAP * Heap, STD_BVP * theBVP, BNDP ** bndp)
    \param corners Array with pointers to all vertices
  */
 static void
-CreateLine(INT i, INT j, HEAP *Heap, PATCH *thePatch, PATCH **corners, PATCH **lines, PATCH **sides,
+CreateLine(INT i, INT j, HEAP *Heap, PATCH **corners, PATCH **lines, PATCH **sides,
            INT *nlines, INT *err)
 {
   INT k, n, m;
-  INT freePatches;
 
   k = 0;
   for (n = 0; n < POINT_PATCH_N (corners[i]); n++)
@@ -699,7 +516,7 @@ CreateLine(INT i, INT j, HEAP *Heap, PATCH *thePatch, PATCH **corners, PATCH **l
   if (k < 2)
     return;
 
-  thePatch =
+  PATCH* thePatch =
     (PATCH *) GetFreelistMemory (Heap, sizeof (LINE_PATCH)
                                  + (k -
                                     1) * sizeof (struct line_on_patch));
@@ -710,7 +527,6 @@ CreateLine(INT i, INT j, HEAP *Heap, PATCH *thePatch, PATCH **corners, PATCH **l
   LINE_PATCH_C0 (thePatch) = i;
   LINE_PATCH_C1 (thePatch) = j;
   k = 0;
-  freePatches = 0;
   for (n = 0; n < POINT_PATCH_N (corners[i]); n++)
     for (m = 0; m < POINT_PATCH_N (corners[j]); m++)
       if (POINT_PATCH_PID (corners[i], n) ==
@@ -722,8 +538,6 @@ CreateLine(INT i, INT j, HEAP *Heap, PATCH *thePatch, PATCH **corners, PATCH **l
           POINT_PATCH_CID (corners[i], n);
         LINE_PATCH_CID1 (thePatch, k) =
           POINT_PATCH_CID (corners[j], m);
-        if (PATCH_IS_FREE (sides[LINE_PATCH_PID (thePatch, k)]))
-          freePatches++;
         k++;
       }
   LINE_PATCH_N (thePatch) = k;
@@ -772,12 +586,7 @@ CreateLine(INT i, INT j, HEAP *Heap, PATCH *thePatch, PATCH **corners, PATCH **l
       }
     }
   }
-  ENDDEBUG if (freePatches == k)
-    PATCH_STATE (thePatch) = PATCH_FREE;
-  else if (freePatches == 0)
-    PATCH_STATE (thePatch) = PATCH_FIXED;
-  else
-    PATCH_STATE (thePatch) = PATCH_BND_OF_FREE;
+  ENDDEBUG
   lines[(*nlines)++] = thePatch;
   PRINTDEBUG (dom, 1, ("lines id %d type %d n %d\n",
                        PATCH_ID (thePatch), PATCH_TYPE (thePatch),
@@ -792,11 +601,9 @@ BVP_Init (const char *name, HEAP * Heap, MESH * Mesh, INT MarkKey)
 {
   STD_BVP *theBVP;
   DOMAIN *theDomain;
-  BOUNDARY_SEGMENT *theSegment;
-  LINEAR_SEGMENT *theLinSegment;
-  PATCH **corners, **sides, *thePatch;
-  unsigned short* segmentsPerPoint, *freeSegmentsPerPoint, *cornerCounters;
-  INT i, j, n, m, maxSubDomains, ncorners, nlines, nsides;
+  PATCH **corners, **sides;
+  unsigned short* segmentsPerPoint, *cornerCounters;
+  INT i, j, n, m, ncorners, nlines, nsides;
 #       ifdef UG_DIM_3
   PATCH **lines;
   INT err;
@@ -817,7 +624,6 @@ BVP_Init (const char *name, HEAP * Heap, MESH * Mesh, INT MarkKey)
   nsides = theDomain->numOfSegments;
 
   /* create parameter patches */
-  maxSubDomains = 0;
   sides = (PATCH **) GetTmpMem (Heap, nsides * sizeof (PATCH *), MarkKey);
   if (sides == NULL)
     return (NULL);
@@ -825,30 +631,26 @@ BVP_Init (const char *name, HEAP * Heap, MESH * Mesh, INT MarkKey)
   for (i = 0; i < nsides; i++)
     sides[i] = NULL;
   theBVP->nsides = nsides;
-  for (theSegment = GetFirstBoundarySegment (theDomain); theSegment != NULL;
-       theSegment = GetNextBoundarySegment (theSegment))
+  for (const boundary_segment& theSegment : theDomain->boundarySegments)
   {
-    if ((theSegment->id < 0) || (theSegment->id >= nsides))
+    if ((theSegment.id < 0) || (theSegment.id >= nsides))
       return (NULL);
-    thePatch = (PATCH *) GetFreelistMemory (Heap, sizeof (PARAMETER_PATCH));
+    PATCH* thePatch = (PATCH *) GetFreelistMemory (Heap, sizeof (PARAMETER_PATCH));
     if (thePatch == NULL)
       return (NULL);
     PATCH_TYPE (thePatch) = PARAMETRIC_PATCH_TYPE;
-    PATCH_ID (thePatch) = theSegment->id;
-    PARAM_PATCH_LEFT (thePatch) = theSegment->left;
-    PARAM_PATCH_RIGHT (thePatch) = theSegment->right;
+    PATCH_ID (thePatch) = theSegment.id;
     for (i = 0; i < 2 * DIM_OF_BND; i++)
-      PARAM_PATCH_POINTS (thePatch, i) = theSegment->points[i];
+      PARAM_PATCH_POINTS (thePatch, i) = theSegment.points[i];
+    // TODO: Remove PARAM_PATCH_RANGE, because it is always (0,1)^d
     for (i = 0; i < DIM_OF_BND; i++)
     {
-      PARAM_PATCH_RANGE (thePatch)[0][i] = theSegment->alpha[i];
-      PARAM_PATCH_RANGE (thePatch)[1][i] = theSegment->beta[i];
+      PARAM_PATCH_RANGE (thePatch)[0][i] = 0;
+      PARAM_PATCH_RANGE (thePatch)[1][i] = 1;
     }
-    PARAM_PATCH_BS (thePatch) = theSegment->BndSegFunc;
-    PARAM_PATCH_BSD (thePatch) = theSegment->data;
-    maxSubDomains = std::max(maxSubDomains, theSegment->left);
-    maxSubDomains = std::max(maxSubDomains, theSegment->right);
-    sides[theSegment->id] = thePatch;
+    PARAM_PATCH_BS (thePatch) = theSegment.BndSegFunc;
+    PARAM_PATCH_BSD (thePatch) = theSegment.data;
+    sides[theSegment.id] = thePatch;
     PRINTDEBUG (dom, 1, ("sides id %d type %d left %d right %d\n",
                          PATCH_ID (thePatch), PATCH_TYPE (thePatch),
                          PARAM_PATCH_LEFT (thePatch),
@@ -858,36 +660,28 @@ BVP_Init (const char *name, HEAP * Heap, MESH * Mesh, INT MarkKey)
                   ("   corners %d", PARAM_PATCH_POINTS (thePatch, i)));
     PRINTDEBUG (dom, 1, ("\n"));
   }
-  for (theLinSegment = GetFirstLinearSegment (theDomain);
-       theLinSegment != NULL;
-       theLinSegment = GetNextLinearSegment (theLinSegment))
+  for (const linear_segment& theLinSegment : theDomain->linearSegments)
   {
-    if ((theLinSegment->id < 0) || (theLinSegment->id >= nsides))
+    if ((theLinSegment.id < 0) || (theLinSegment.id >= nsides))
       return (NULL);
-    thePatch = (PATCH *) GetFreelistMemory (Heap, sizeof (LINEAR_PATCH));
+    PATCH* thePatch = (PATCH *) GetFreelistMemory (Heap, sizeof (LINEAR_PATCH));
     if (thePatch == NULL)
       return (NULL);
     PATCH_TYPE (thePatch) = LINEAR_PATCH_TYPE;
-    PATCH_ID (thePatch) = theLinSegment->id;
-    LINEAR_PATCH_LEFT (thePatch) = theLinSegment->left;
-    LINEAR_PATCH_RIGHT (thePatch) = theLinSegment->right;
-    LINEAR_PATCH_N (thePatch) = theLinSegment->n;
-    for (j = 0; j < theLinSegment->n; j++)
+    PATCH_ID (thePatch) = theLinSegment.id;
+    LINEAR_PATCH_N (thePatch) = theLinSegment.n;
+    for (j = 0; j < theLinSegment.n; j++)
     {
-      LINEAR_PATCH_POINTS (thePatch, j) = theLinSegment->points[j];
+      LINEAR_PATCH_POINTS (thePatch, j) = theLinSegment.points[j];
       for (i = 0; i < DIM; i++)
-        LINEAR_PATCH_POS (thePatch, j)[i] = theLinSegment->x[j][i];
+        LINEAR_PATCH_POS (thePatch, j)[i] = theLinSegment.x[j][i];
     }
-    maxSubDomains = std::max(maxSubDomains, theLinSegment->left);
-    maxSubDomains = std::max(maxSubDomains, theLinSegment->right);
-    sides[theLinSegment->id] = thePatch;
+    sides[theLinSegment.id] = thePatch;
     PRINTDEBUG (dom, 1, ("sides id %d type %d left %d right %d\n",
                          PATCH_ID (thePatch), PATCH_TYPE (thePatch),
                          LINEAR_PATCH_LEFT (thePatch),
                          LINEAR_PATCH_RIGHT (thePatch)));
   }
-  theBVP->numOfSubdomains = maxSubDomains;
-  PRINTDEBUG (dom, 1, (" bvp nsubcf %x\n", theBVP->numOfSubdomains));
   for (i = 0; i < nsides; i++)
     if (sides[i] == NULL)
       return (NULL);
@@ -900,7 +694,6 @@ BVP_Init (const char *name, HEAP * Heap, MESH * Mesh, INT MarkKey)
 
   /* precompute the number of segments at each point patch */
   segmentsPerPoint = (unsigned short*)calloc(ncorners,sizeof(unsigned short));
-  freeSegmentsPerPoint = (unsigned short*)calloc(ncorners,sizeof(unsigned short));
 
   for (j = 0; j < nsides; j++) {
 
@@ -908,20 +701,10 @@ BVP_Init (const char *name, HEAP * Heap, MESH * Mesh, INT MarkKey)
       for (n = 0; n < LINEAR_PATCH_N (sides[j]); n++)
         segmentsPerPoint[LINEAR_PATCH_POINTS (sides[j], n)]++;
 
-      if (PATCH_IS_FREE(sides[j]))
-        for (n = 0; n < LINEAR_PATCH_N (sides[j]); n++)
-          freeSegmentsPerPoint[LINEAR_PATCH_POINTS (sides[j], n)]++;
-
     } else if (PATCH_TYPE (sides[j]) == PARAMETRIC_PATCH_TYPE) {
       for (n = 0; n < 2 * DIM_OF_BND; n++)
         if (PARAM_PATCH_POINTS (sides[j], n) >= 0)       /* Entry may be -1 for triangular faces */
           segmentsPerPoint[PARAM_PATCH_POINTS (sides[j], n)]++;
-
-      if (PATCH_IS_FREE(sides[j]))
-        for (n = 0; n < 2 * DIM_OF_BND; n++)
-          if (PARAM_PATCH_POINTS (sides[j], n) >= 0)     /* Entry may be -1 for triangular faces */
-            freeSegmentsPerPoint[PARAM_PATCH_POINTS (sides[j], n)]++;
-
     }
 
   }
@@ -931,7 +714,7 @@ BVP_Init (const char *name, HEAP * Heap, MESH * Mesh, INT MarkKey)
 
     m = segmentsPerPoint[i];
 
-    thePatch =
+    PATCH* thePatch =
       (PATCH *) GetFreelistMemory (Heap, sizeof (POINT_PATCH)
                                    + (m-1) * sizeof (struct point_on_patch));
     if (thePatch == NULL)
@@ -971,27 +754,8 @@ BVP_Init (const char *name, HEAP * Heap, MESH * Mesh, INT MarkKey)
     }
   }
 
-  for (i = 0; i < ncorners; i++) {
-    /* Shouldn't the 'thePatch' be replaced 'corners[i]' in this loop?  OS */
-    if (freeSegmentsPerPoint[i] == cornerCounters[i])
-      PATCH_STATE (thePatch) = PATCH_FREE;
-    else if (freeSegmentsPerPoint[i] == 0)
-      PATCH_STATE (thePatch) = PATCH_FIXED;
-    else
-      PATCH_STATE (thePatch) = PATCH_BND_OF_FREE;
-
-    PRINTDEBUG (dom, 1, ("corners id %d type %d n %d\n",
-                         PATCH_ID (thePatch), PATCH_TYPE (thePatch),
-                         POINT_PATCH_N (thePatch)));
-    for (j = 0; j < POINT_PATCH_N (thePatch); j++)
-      PRINTDEBUG (dom, 1, (" pid %d cid %d\n",
-                           POINT_PATCH_PID (thePatch, j),
-                           POINT_PATCH_CID (thePatch, j)));
-  }
-
   /* Return memory that will not be used anymore */
   free(segmentsPerPoint);
-  free(freeSegmentsPerPoint);
   free(cornerCounters);
 
   /* create line patches */
@@ -1034,7 +798,7 @@ BVP_Init (const char *name, HEAP * Heap, MESH * Mesh, INT MarkKey)
         if ( bnd_edges.insert(z).second )       /* true if bnd_edges didn't contain z yet */
         {
           /* Insert the line into the boundary data structure */
-          CreateLine(min, max, Heap, thePatch, corners, lines, sides, &nlines, &err);
+          CreateLine(min, max, Heap, corners, lines, sides, &nlines, &err);
         }
         else
           bnd_edges.erase(z);
@@ -1064,7 +828,7 @@ BVP_Init (const char *name, HEAP * Heap, MESH * Mesh, INT MarkKey)
         if ( bnd_edges.insert(z).second )            /* true if bnd_edges didn't contain z yet */
         {
           /* Insert the line into the boundary data structure */
-          CreateLine(min, max, Heap, thePatch, corners, lines, sides, &nlines, &err);
+          CreateLine(min, max, Heap, corners, lines, sides, &nlines, &err);
         }
         else
           bnd_edges.erase(z);
@@ -1085,7 +849,7 @@ BVP_Init (const char *name, HEAP * Heap, MESH * Mesh, INT MarkKey)
   n = 0;
   for (i = 0; i < ncorners; i++)
   {
-    thePatch = corners[i];
+    PATCH* thePatch = corners[i];
     for (j = 0; j < POINT_PATCH_N (thePatch); j++)
       POINT_PATCH_PID (thePatch, j) += m;
     theBVP->patches[n++] = thePatch;
@@ -1093,7 +857,7 @@ BVP_Init (const char *name, HEAP * Heap, MESH * Mesh, INT MarkKey)
 #ifdef UG_DIM_3
   for (i = 0; i < nlines; i++)
   {
-    thePatch = lines[i];
+    PATCH* thePatch = lines[i];
     PATCH_ID (thePatch) = n;
     for (j = 0; j < LINE_PATCH_N (thePatch); j++)
       LINE_PATCH_PID (thePatch, j) += m;
@@ -1102,7 +866,7 @@ BVP_Init (const char *name, HEAP * Heap, MESH * Mesh, INT MarkKey)
 #endif
   for (i = 0; i < nsides; i++)
   {
-    thePatch = sides[i];
+    PATCH* thePatch = sides[i];
     PATCH_ID (thePatch) = n;
     theBVP->patches[n++] = thePatch;
   }
@@ -1195,7 +959,6 @@ BVP_SetBVPDesc (BVP * aBVP, BVP_DESC * theBVPDesc)
   strcpy (BVPD_NAME (theBVPDesc), ENVITEM_NAME (theBVP));
 
   /* the domain part */
-  BVPD_NSUBDOM (theBVPDesc) = theBVP->numOfSubdomains;
   BVPD_NCOEFFF (theBVPDesc) = theBVP->numOfCoeffFct;
   BVPD_NUSERF (theBVPDesc) = theBVP->numOfUserFct;
   BVPD_CONFIG (theBVPDesc) = theBVP->ConfigProc;
@@ -1260,7 +1023,7 @@ BVP_Check (BVP * aBVP)
 }
 
 static INT
-GetNumberOfCommonPatches (PATCH * p0, PATCH * p1, INT * Pid)
+GetNumberOfCommonPatches (const PATCH * p0, const PATCH * p1, INT * Pid)
 {
   INT i, j, cnt, np0, np1, pid;
 
@@ -1284,7 +1047,7 @@ GetNumberOfCommonPatches (PATCH * p0, PATCH * p1, INT * Pid)
 
 #ifdef UG_DIM_3
 static INT
-GetCommonPatchId (PATCH * p0, PATCH * p1, INT k)
+GetCommonPatchId (const PATCH * p0, const PATCH * p1, INT k)
 {
   INT i, j, cnt;
 
@@ -1302,7 +1065,6 @@ static INT
 GetCommonLinePatchId (PATCH * p0, PATCH * p1)
 {
   INT i, k, l, cnt, cnt1;
-  PATCH *p;
 
   if (PATCH_TYPE (p0) == LINE_PATCH_TYPE)
     return (PATCH_ID (p0));
@@ -1316,7 +1078,7 @@ GetCommonLinePatchId (PATCH * p0, PATCH * p1)
 
   for (k = currBVP->ncorners; k < currBVP->sideoffset; k++)
   {
-    p = currBVP->patches[k];
+    PATCH *p = currBVP->patches[k];
     if (LINE_PATCH_N (p) != cnt)
       continue;
     cnt1 = 0;
@@ -1332,184 +1094,6 @@ GetCommonLinePatchId (PATCH * p0, PATCH * p1)
 }
 #endif
 
-#define BN_RES          100
-
-static int
-DropPerpendicularOnSegment (PATCH * patch, double range[][DIM_OF_BND],
-                            const double global[], double local[],
-                            double *mindist2)
-{
-  double sa = range[0][0];
-  double sb = range[1][0];
-  double ds = (sb - sa) / ((double) BN_RES);
-  int k;
-#if (DIM==3)
-  double ta = range[0][1];
-  double tb = range[1][1];
-  double dt = (tb - ta) / ((double) BN_RES);
-  int l;
-#endif
-
-  for (k = 0; k <= BN_RES; k++)
-  {
-    DOUBLE lambda[DIM_OF_BND];
-    DOUBLE_VECTOR point, diff;
-    double dist2;
-
-    lambda[0] = (k == BN_RES) ? sb : sa + k * ds;
-
-#if (DIM==3)
-    for (l = 0; l <= BN_RES; l++)
-    {
-
-      lambda[1] = (l == BN_RES) ? tb : ta + l * dt;
-#endif
-
-    if (PatchGlobal (patch, lambda, point))
-      return 1;
-    V_DIM_SUBTRACT (point, global, diff);
-    dist2 = V_DIM_SCAL_PROD (diff, diff);
-    if (*mindist2 > dist2)
-    {
-      *mindist2 = dist2;
-      V_BDIM_COPY (lambda, local);
-    }
-#if (DIM==3)
-  }
-#endif
-  }
-  return 0;
-}
-
-static int
-ResolvePointOnSegment (PATCH * patch, int depth, double resolution2,
-                       double range[][DIM_OF_BND], const double global[],
-                       double local[])
-{
-  double ds = (range[1][0] - range[0][0]) / ((double) BN_RES);
-#if (DIM==3)
-  double dt = (range[1][1] - range[0][1]) / ((double) BN_RES);
-#endif
-  double new_range[2][DIM_OF_BND];
-  DOUBLE mindist2 = MAX_D;
-
-  new_range[0][0] = local[0] - ds;
-  new_range[1][0] = local[0] + ds;
-#if (DIM==3)
-  new_range[0][1] = local[1] - dt;
-  new_range[1][1] = local[1] + dt;
-#endif
-
-  if (DropPerpendicularOnSegment (patch, new_range, global, local, &mindist2))
-    return 1;
-  if (mindist2 > resolution2)
-  {
-    if (depth > 0)
-    {
-      /* recursive call */
-      if (ResolvePointOnSegment
-            (patch, depth - 1, resolution2, new_range, global, local))
-        return 1;
-    }
-    else
-      return 2;
-  }
-  return 0;
-}
-
-static INT
-AddBoundaryElement (INT n, INT * nodelist,
-                    INT left, INT right, INT *** corners, INT * sides)
-{
-  if (left > 0)
-  {
-    if (corners != NULL)
-    {
-      corners[left][sides[left]][0] = nodelist[0];
-      corners[left][sides[left]][1] = nodelist[1];
-      corners[left][sides[left]][2] = nodelist[2];
-    }
-    sides[left]++;
-  }
-  if (right > 0)
-  {
-    if (corners != NULL)
-    {
-      corners[right][sides[right]][0] = nodelist[0];
-      corners[right][sides[right]][1] = nodelist[2];
-      corners[right][sides[right]][2] = nodelist[1];
-    }
-    sides[right]++;
-  }
-
-  return (0);
-}
-
-static INT
-AddBoundaryElements (INT n, INT m,
-                     INT c0, INT c1, INT c2, INT c3,
-                     INT s0, INT s1, INT s2, INT s3,
-                     INT left, INT right, INT *** corners, INT * sides)
-{
-  INT nodelist[3];
-
-  PRINTDEBUG (dom, 1, ("    add n %d m %d c0 %d c1 %d s0 %d s1 %d\n",
-                       n, m, c0, c1, s0, s1));
-  if (m < n)
-  {
-    if (n == 1)
-    {
-      nodelist[0] = c0;
-      nodelist[1] = c2;
-      nodelist[2] = c1;
-      AddBoundaryElement (3, nodelist, left, right, corners, sides);
-    }
-    else
-    {
-      nodelist[0] = c0;
-      nodelist[1] = c2;
-      nodelist[2] = s0;
-      AddBoundaryElement (3, nodelist, left, right, corners, sides);
-      c0 = s0;
-      if (s0 < s1)
-        s0++;
-      else
-        s0--;
-      AddBoundaryElements (n - 1, m, c0, c1, c2, c3, s0, s1, s2, s3,
-                           left, right, corners, sides);
-    }
-  }
-  else
-  {
-    if (m == 1)
-    {
-      nodelist[0] = c0;
-      nodelist[1] = c2;
-      nodelist[2] = c1;
-      AddBoundaryElement (3, nodelist, left, right, corners, sides);
-      nodelist[0] = c1;
-      nodelist[1] = c2;
-      nodelist[2] = c3;
-      AddBoundaryElement (3, nodelist, left, right, corners, sides);
-    }
-    else
-    {
-      nodelist[0] = c2;
-      nodelist[1] = s2;
-      nodelist[2] = c0;
-      AddBoundaryElement (3, nodelist, left, right, corners, sides);
-      c2 = s2;
-      if (s2 < s3)
-        s2++;
-      else
-        s2--;
-      AddBoundaryElements (n, m - 1, c0, c1, c2, c3, s0, s1, s2, s3,
-                           left, right, corners, sides);
-    }
-  }
-
-  return (0);
-}
 
 /****************************************************************************/
 /****************************************************************************/
@@ -1520,7 +1104,7 @@ AddBoundaryElements (INT n, INT m,
 /****************************************************************************/
 
 static INT
-PatchGlobal (const PATCH * p, DOUBLE * lambda, DOUBLE * global)
+PatchGlobal (const PATCH * p, DOUBLE * lambda, Dune::FieldVector<DOUBLE,DIM>& global)
 {
   if (PATCH_TYPE (p) == PARAMETRIC_PATCH_TYPE)
     return ((*PARAM_PATCH_BS (p))(PARAM_PATCH_BSD (p), lambda, global));
@@ -1559,58 +1143,9 @@ PatchGlobal (const PATCH * p, DOUBLE * lambda, DOUBLE * global)
 }
 
 static INT
-FreeBNDS_Global (BND_PS * ps, DOUBLE * local, DOUBLE * global)
+local2lambda (BND_PS * ps, const Dune::FieldVector<DOUBLE,DIM_OF_BND>& local, DOUBLE lambda[])
 {
-  BND_PS **ppt;
-  PATCH *p;
-  DOUBLE *pos[4];
-  INT i;
-
-  p = currBVP->patches[ps->patch_id];
-  if (p == NULL)
-    return (1);
-
-  /* get corner coordinates */
-  ppt = (BND_PS **) BND_DATA (ps);
-  ASSERT (BND_N (ps) <= 4);
-  for (i = 0; i < BND_N (ps); i++)
-  {
-    ASSERT (ppt != NULL);
-    pos[i] = (DOUBLE *) BND_DATA (*(ppt++));
-  }
-
-  /* calculate global coordinates */
-#ifdef UG_DIM_2
-  for (i = 0; i < DIM; i++)
-    global[i] = (1.0 - local[0]) * pos[0][i] + local[0] * pos[1][i];
-#endif
-#ifdef UG_DIM_3
-  switch (ps->n)
-  {
-  case 3 :
-    for (i = 0; i < DIM; i++)
-      global[i] = (1.0 - local[0] - local[1]) * pos[0][i]
-                  + local[0] * pos[1][i] + local[1] * pos[2][i];
-    break;
-  case 4 :
-    for (i = 0; i < DIM; i++)
-      global[i] = (1.0 - local[0]) * (1.0 - local[1]) * pos[0][i]
-                  + local[0] * (1.0 - local[1]) * pos[1][i]
-                  + local[0] * local[1] * pos[2][i]
-                  + (1.0 - local[0]) * local[1] * pos[3][i];
-    break;
-  }
-#endif
-
-  return (0);
-}
-
-static INT
-local2lambda (BND_PS * ps, DOUBLE local[], DOUBLE lambda[])
-{
-  PATCH *p;
-
-  p = currBVP->patches[ps->patch_id];
+  const PATCH *p = currBVP->patches[ps->patch_id];
 
   if ((PATCH_TYPE (p) == PARAMETRIC_PATCH_TYPE)
       || (PATCH_TYPE (p) == LINEAR_PATCH_TYPE))
@@ -1645,39 +1180,14 @@ local2lambda (BND_PS * ps, DOUBLE local[], DOUBLE lambda[])
   return (0);
 }
 
-/* domain interface function: for description see domain.h */
-INT NS_DIM_PREFIX
-BNDS_Global (BNDS * aBndS, DOUBLE * local, DOUBLE * global)
-{
-  BND_PS *ps;
-  PATCH *p;
-  DOUBLE lambda[DIM_OF_BND];
-
-  ps = (BND_PS *) aBndS;
-  p = currBVP->patches[ps->patch_id];
-  if (p == NULL)
-    return (1);
-
-  PRINTDEBUG (dom, 1, (" Bnds global loc %f pid %d\n",
-                       local[0], PATCH_ID (p)));
-
-  if (PATCH_IS_FREE (p))
-    return (FreeBNDS_Global (ps, local, global));
-
-  if (local2lambda (ps, local, lambda))
-    return (1);
-
-  return (PatchGlobal (p, lambda, global));
-}
-
-static INT
+static bool
 SideIsCooriented (BND_PS * ps)
 {
 #       ifdef UG_DIM_2
   if (BND_LOCAL (ps, 1)[0] > BND_LOCAL (ps, 0)[0])
-    return (YES);
+    return true;
   else
-    return (NO);
+    return false;
 #       endif
 
 #       ifdef UG_DIM_3
@@ -1693,9 +1203,9 @@ SideIsCooriented (BND_PS * ps)
   ASSERT (fabs (vp) > SMALL_C);
 
   if (vp > SMALL_C)
-    return (YES);
+    return true;
   else
-    return (NO);
+    return false;
 #       endif
 }
 
@@ -1742,16 +1252,14 @@ BNDS_BndSDesc (BNDS * theBndS, INT * id, INT * nbid)
 
 /* domain interface function: for description see domain.h */
 BNDP *NS_DIM_PREFIX
-BNDS_CreateBndP (HEAP * Heap, BNDS * aBndS, DOUBLE * local)
+BNDS_CreateBndP (HEAP * Heap, BNDS * aBndS, const FieldVector<DOUBLE,DIM_OF_BND>& local)
 {
   BND_PS *ps, *pp;
-  PATCH *p;
 
   if (aBndS == NULL)
     return (NULL);
 
   ps = (BND_PS *) aBndS;
-  p = currBVP->patches[ps->patch_id];
 
   pp = (BND_PS *) GetFreelistMemory (Heap, sizeof (BND_PS));
   if (pp == NULL)
@@ -1763,17 +1271,6 @@ BNDS_CreateBndP (HEAP * Heap, BNDS * aBndS, DOUBLE * local)
   if (local2lambda (ps, local, pp->local[0]))
     return (NULL);
 
-  if (!PATCH_IS_FIXED (p))
-  {
-    /* store global coordinates */
-    BND_DATA (pp) = GetFreelistMemory (Heap, DIM * sizeof (DOUBLE));
-    if (BND_DATA (pp) == NULL)
-      return (NULL);
-
-    if (FreeBNDS_Global (ps, pp->local[0], (DOUBLE *) BND_DATA (pp)))
-      return (NULL);
-  }
-
   PRINTDEBUG (dom, 1, (" BNDP s %d\n", pp->patch_id));
 
   return ((BNDP *) pp);
@@ -1787,14 +1284,15 @@ BNDS_CreateBndP (HEAP * Heap, BNDS * aBndS, DOUBLE * local)
 /****************************************************************************/
 /****************************************************************************/
 
-static INT
-BndPointGlobal (const BNDP * aBndP, DOUBLE * global)
+/* domain interface function: for description see domain.h */
+INT NS_DIM_PREFIX
+BNDP_Global (const BNDP * aBndP, FieldVector<DOUBLE,DIM>& global)
 {
   using std::abs;
   BND_PS *ps;
   PATCH *p, *s;
   INT j, k;
-  DOUBLE pglobal[DIM];
+  FieldVector<DOUBLE,DIM> pglobal;
 
   ps = (BND_PS *) aBndP;
   p = currBVP->patches[ps->patch_id];
@@ -1871,26 +1369,6 @@ BndPointGlobal (const BNDP * aBndP, DOUBLE * global)
   REP_ERR_RETURN (1);
 }
 
-/* domain interface function: for description see domain.h */
-INT NS_DIM_PREFIX
-BNDP_Global (BNDP * aBndP, DOUBLE * global)
-{
-  BND_PS *ps = (BND_PS *) aBndP;
-  DOUBLE *pos;
-  INT i;
-
-  if (!PATCH_IS_FIXED (currBVP->patches[ps->patch_id]))
-  {
-    /* copy globals */
-    pos = (DOUBLE *) BND_DATA (ps);
-    for (i = 0; i < DIM; i++)
-      global[i] = pos[i];
-    return (0);
-  }
-
-  return (BndPointGlobal (aBndP, global));
-}
-
 /* domain interface function: for description see domain.h */
 INT NS_DIM_PREFIX
 BNDP_BndPDesc (BNDP * theBndP, INT * move)
@@ -1905,16 +1383,16 @@ BNDP_BndPDesc (BNDP * theBndP, INT * move)
   {
   case PARAMETRIC_PATCH_TYPE :
   case LINEAR_PATCH_TYPE :
-    *move = PATCH_IS_FREE (p) ? DIM : DIM_OF_BND;
+    *move = DIM_OF_BND;
     return (0);
 
   case POINT_PATCH_TYPE :
-    *move = PATCH_IS_FREE (p) ? DIM : 0;
+    *move = 0;
     return (0);
 
 #               ifdef UG_DIM_3
   case LINE_PATCH_TYPE :
-    *move = PATCH_IS_FREE (p) ? DIM : 1;
+    *move = 1;
     return (0);
 #               endif
   }
@@ -1926,12 +1404,10 @@ BNDP_BndPDesc (BNDP * theBndP, INT * move)
 INT NS_DIM_PREFIX
 BNDP_BndEDesc (BNDP * aBndP0, BNDP * aBndP1)
 {
-  BND_PS *bp0, *bp1;
+  const BND_PS *bp0 = (BND_PS*)aBndP0;
+  const BND_PS *bp1 = (BND_PS*)aBndP1;
 
-  bp0 = (BND_PS *) aBndP0;
-  bp1 = (BND_PS *) aBndP1;
-
-  if ((bp0 == NULL) || (bp1 == NULL))
+  if ((bp0 == nullptr) || (bp1 == nullptr))
     REP_ERR_RETURN (1);
 
   return (0);
@@ -1941,7 +1417,7 @@ BNDP_BndEDesc (BNDP * aBndP0, BNDP * aBndP1)
 BNDS *NS_DIM_PREFIX
 BNDP_CreateBndS (HEAP * Heap, BNDP ** aBndP, INT n)
 {
-  BND_PS *bp[4], *bs, **pps;
+  BND_PS *bp[4], *bs;
   PATCH *p[4];
   DOUBLE *lambda[4];
   INT i, j, l, pid;
@@ -2037,18 +1513,6 @@ BNDP_CreateBndS (HEAP * Heap, BNDP ** aBndP, INT n)
 
   PRINTDEBUG (dom, 1, (" Create BNDS %x %d\n", bs, pid));
 
-  if (!PATCH_IS_FIXED (currBVP->patches[pid]))
-  {
-    /* store corner patch pointers */
-    BND_DATA (bs) = GetFreelistMemory (Heap, n * sizeof (BND_PS *));
-    if (BND_DATA (bs) == NULL)
-      return (NULL);
-
-    pps = (BND_PS **) BND_DATA (bs);
-    for (i = 0; i < n; i++)
-      *(pps++) = bp[i];
-  }
-
   return ((BNDS *) bs);
 }
 
@@ -2124,16 +1588,6 @@ BNDP_CreateBndP (HEAP * Heap, BNDP * aBndP0, BNDP * aBndP1, DOUBLE lcoord)
                            LINE_PATCH_PID (p, l), l,
                            bp->local[l][0], bp->local[l][1]));
 
-    if (!PATCH_IS_FIXED (p))
-    {
-      /* store global coordinates */
-      BND_DATA (bp) = GetFreelistMemory (Heap, DIM * sizeof (DOUBLE));
-      if (BND_DATA (bp) == NULL)
-        return (NULL);
-
-      if (BNDP_Global ((BNDP *) bp, (DOUBLE *) BND_DATA (bp)))
-        return (NULL);
-    }
     return ((BNDP *) bp);
   }
 #endif
@@ -2152,54 +1606,9 @@ BNDP_CreateBndP (HEAP * Heap, BNDP * aBndP0, BNDP * aBndP1, DOUBLE lcoord)
         break;
       }
 
-  if (!PATCH_IS_FIXED (currBVP->patches[bp->patch_id]))
-  {
-    DOUBLE *x, *a, *b;
-
-    /* store global coordinates */
-    BND_DATA (bp) = GetFreelistMemory (Heap, DIM * sizeof (DOUBLE));
-    if (BND_DATA (bp) == NULL)
-      return (NULL);
-
-    x = (DOUBLE *) BND_DATA (bp);
-    a = (DOUBLE *) BND_DATA (bp0);
-    b = (DOUBLE *) BND_DATA (bp1);
-    ASSERT (a != NULL);
-    ASSERT (b != NULL);
-    for (i = 0; i < DIM; i++)
-      x[i] = a[i] * (1.0 - lcoord) + b[i] * lcoord;
-  }
-
   return ((BNDP *) bp);
 }
 
-/* domain interface function: for description see domain.h */
-INT NS_DIM_PREFIX
-BNDP_Move (BNDP * aBndP, const DOUBLE global[])
-{
-  BND_PS *ps;
-  DOUBLE *pos;
-  INT i;
-
-#ifdef ModelP
-  /* TODO: parallel version */
-  PrintErrorMessage ('E', "BNDP_Move", "parallel not implemented");
-  ASSERT (false);
-#endif
-
-  ps = (BND_PS *) aBndP;
-  if (PATCH_IS_FREE (currBVP->patches[ps->patch_id]))
-  {
-    /* copy globals */
-    pos = (DOUBLE *) BND_DATA (ps);
-    for (i = 0; i < DIM; i++)
-      pos[i] = global[i];
-    return (0);
-  }
-
-  return (1);
-}
-
 /* domain interface function: for description see domain.h */
 INT NS_DIM_PREFIX
 BNDP_SaveInsertedBndP (BNDP * theBndP, char *data, INT max_data_size)
@@ -2235,13 +1644,13 @@ BNDP_SaveInsertedBndP (BNDP * theBndP, char *data, INT max_data_size)
   PRINTDEBUG (dom, 1, (" Insert pid %d %d\n", bp->patch_id, pid));
 
 #ifdef UG_DIM_2
-  if (sprintf (data, "bn %d %f", pid, (float) bp->local[0][0]) >
+  if (snprintf (data, max_data_size, "bn %d %f", pid, (float) bp->local[0][0]) >
       max_data_size)
     return (1);
 #endif
 
 #ifdef UG_DIM_3
-  if (sprintf (data, "bn %d %f %f", (int) pid,
+  if (snprintf (data, max_data_size, "bn %d %f %f", (int) pid,
                (float) bp->local[0][0],
                (float) bp->local[0][1]) > max_data_size)
     return (1);
@@ -2276,8 +1685,6 @@ BNDP_Dispose (HEAP * Heap, BNDP * theBndP)
     return (0);
 
   ps = (BND_PS *) theBndP;
-  if (!PATCH_IS_FIXED (currBVP->patches[ps->patch_id]))
-    DisposeMem(Heap, BND_DATA (ps));
   DisposeMem(Heap, ps);
   return 0;
 }
@@ -2292,8 +1699,6 @@ BNDS_Dispose (HEAP * Heap, BNDS * theBndS)
     return (0);
 
   ps = (BND_PS *) theBndS;
-  if (!PATCH_IS_FIXED (currBVP->patches[ps->patch_id]))
-    DisposeMem(Heap, BND_DATA (ps));
   DisposeMem(Heap, ps);
   return 0;
 }
@@ -2320,16 +1725,6 @@ BNDP_SaveBndP (BNDP * BndP)
     if (Bio_Write_mdouble (DIM - 1, dList))
       return (1);
   }
-  if (!PATCH_IS_FIXED (currBVP->patches[BND_PATCH_ID (BndP)]))
-  {
-    DOUBLE *pos = (DOUBLE *) BND_DATA (bp);
-
-    /* save free boundary point coordinates */
-    for (j = 0; j < DIM; j++)
-      dList[j] = pos[j];
-    if (Bio_Write_mdouble (DIM, dList))
-      return (1);
-  }
 
   return (0);
 }
@@ -2357,16 +1752,6 @@ BNDP_SaveBndP_Ext (BNDP * BndP)
     if (Bio_Write_mdouble (DIM - 1, dList))
       return (1);
   }
-  if (!PATCH_IS_FIXED (currBVP->patches[BND_PATCH_ID (BndP)]))
-  {
-    DOUBLE *pos = (DOUBLE *) BND_DATA (bp);
-
-    /* save free boundary point coordinates */
-    for (j = 0; j < DIM; j++)
-      dList[j] = pos[j];
-    if (Bio_Write_mdouble (DIM, dList))
-      return (1);
-  }
 
   return (0);
 }
@@ -2397,22 +1782,6 @@ BNDP_LoadBndP (BVP * theBVP, HEAP * Heap)
     for (j = 0; j < DIM - 1; j++)
       bp->local[i][j] = dList[j];
   }
-  /* load free boundary points properly */
-  if (!PATCH_IS_FIXED (currBVP->patches[pid]))
-  {
-    DOUBLE *pos;
-
-    /* read global coordinates */
-    BND_DATA (bp) = GetFreelistMemory (Heap, DIM * sizeof (DOUBLE));
-    if (BND_DATA (bp) == NULL)
-      return (NULL);
-
-    if (Bio_Read_mdouble (DIM, dList))
-      return (NULL);
-    pos = (DOUBLE *) BND_DATA (bp);
-    for (j = 0; j < DIM; j++)
-      pos[j] = dList[j];
-  }
 
   return ((BNDP *) bp);
 }
@@ -2478,8 +1847,6 @@ InitDom (void)
     PrintErrorMessage ('F', "InitDom", "could not install '/Domains' dir");
     return (__LINE__);
   }
-  theBdrySegVarID = GetNewEnvVarID ();
-  theLinSegVarID = GetNewEnvVarID ();
 
   /* install the /BVP directory */
   theBVPDirID = GetNewEnvDirID ();
