@@ -66,6 +66,7 @@
 #include <cstring>
 
 #include <algorithm>
+#include <array>
 
 /* gm */
 #include "rm.h"
@@ -227,13 +228,13 @@ static struct {
   HEAP *heap;                                                   /* multigrid heap						*/
 
   HRULE **hash_table;                                   /* hash table							*/
-  HRULE **hrule[TAGS];                          /* tables with hrules sorted by id		*/
+  std::array<HRULE**, TAGS> hrule;                          /* tables with hrules sorted by id		*/
 
-  long maxrule[TAGS];                                   /* max rule id per tag (rm+er)			*/
+  std::array<long, TAGS> maxrule;                                   /* max rule id per tag (rm+er)			*/
   long maxrules;                                        /* max rule id (rm+er)					*/
-  long nelem_inspected[TAGS];                   /* elements getting er-rules per tag	*/
+  std::array<long, TAGS> nelem_inspected;                   /* elements getting er-rules per tag	*/
   long nelems_inspected;                        /* elements getting er-rules			*/
-  long nelem_not_inspected[TAGS];       /* elements having rm-rules per tag		*/
+  std::array<long, TAGS> nelem_not_inspected;       /* elements having rm-rules per tag		*/
   long nelems_not_inspected;                    /* elements having rm-rules				*/
 
         #ifdef ModelP
@@ -271,12 +272,11 @@ static struct {
    doctext_disabled*/
 /****************************************************************************/
 
-static DOUBLE Corner2DCorners (INT n, SHORT corners[])
+static DOUBLE Corner2DCorners (INT n, const SHORT corners[])
 {
   DOUBLE dco = corners[0];
-  int i;
 
-  for (i=1; i<n; i++)
+  for (int i = 1; i < n; i++)
   {
     dco *= MAX_REFINED_CORNERS_DIM;
     dco += corners[i];
@@ -310,9 +310,7 @@ static DOUBLE Corner2DCorners (INT n, SHORT corners[])
 
 static void DCorners2Corners (INT n, DOUBLE dco, SHORT corners[])
 {
-  int i;
-
-  for (i=n-1; i>=0; i--)
+  for (int i = n-1; i >= 0; i--)
   {
     DOUBLE x = floor(dco/((DOUBLE)MAX_REFINED_CORNERS_DIM));
     corners[i] = (SHORT)(dco-x*MAX_REFINED_CORNERS_DIM);
@@ -343,10 +341,9 @@ static void DCorners2Corners (INT n, DOUBLE dco, SHORT corners[])
 static void FillOrderedSons (const ERULE *er, DOUBLE oco[])
 {
   SHORT corners[MAX_CORNERS_OF_ELEM_DIM];
-  int s;
 
   /* sort corners of each son */
-  for (s=0; s<ER_NSONS(er); s++)
+  for (int s = 0; s < ER_NSONS(er); s++)
   {
     DCorners2Corners(ER_NCO(er,s),ER_DCO(er,s),corners);
     std::sort(corners, corners + ER_NCO(er,s));
@@ -380,13 +377,11 @@ static void FillOrderedSons (const ERULE *er, DOUBLE oco[])
 #if (defined UG_DIM_3) || (defined __DEBUG_ER__)
 static INT Hash_Init (int MarkKey)
 {
-  int i;
-
   global.hash_table = (HRULE**) GetTmpMem(global.heap,HASH_SIZE*sizeof(HRULE*),MarkKey);
   if (global.hash_table==NULL)
     REP_ERR_RETURN(1);
 
-  for (i=0; i<HASH_SIZE; i++)
+  for (int i = 0; i < HASH_SIZE; i++)
     global.hash_table[i] = NULL;
 
   return (0);
@@ -426,7 +421,7 @@ static HRID Hash_InsertRule (INT etag, INT key, const ERULE *er, const DOUBLE oc
   // I think that nullptr can replace the call to GetCurrentMultigrid, because that method
   // has been returning nullptr for a long time.
   // In other words: it seems the method we are in is never called.
-  HRULE *hr       = (HRULE*) GetMemoryForObject(nullptr/*GetCurrentMultigrid()*/,size,MAOBJ);
+  HRULE *hr       = (HRULE*) GetMemoryForObject(nullptr/*GetCurrentMultigrid()*/,size,NOOBJ);
   HRID id         = global.maxrule[etag]++;
 
 
@@ -471,18 +466,17 @@ static HRID Hash_InsertRule (INT etag, INT key, const ERULE *er, const DOUBLE oc
    doctext_disabled*/
 /****************************************************************************/
 
-static INT SonsAreEqual (INT nsons, const DOUBLE oco[], const HRULE *hr)
+static bool SonsAreEqual (INT nsons, const DOUBLE oco[], const HRULE *hr)
 {
   if (nsons!=HR_NSONS(hr))
-    return (NO);
-  else
+    return false;
+
+  for (int s = 0; s < nsons; s++)
   {
-    int s;
-    for (s=0; s<nsons; s++)
-      if (oco[s]!=HR_OCO(hr,s))
-        return (NO);
-    return (YES);
+    if (oco[s] != HR_OCO(hr, s))
+        return false;
   }
+  return true;
 }
 
 /****************************************************************************/
@@ -517,25 +511,23 @@ static HRID GetRuleID
 )
 {
   DOUBLE key = 0;
-  HRULE *hr;
   DOUBLE oco[MAX_SONS];
-  int s,h;
 
   global.nelem_inspected[etag]++;
   global.nelems_inspected++;
 
-  PRINTDEBUG(gm,ER_DBG_ELEM,(ELEM_INFO("GetRuleID",YES,elem,ER_NSONS(er))));
+  PRINTDEBUG(gm,ER_DBG_ELEM,(ELEM_INFO("GetRuleID",true,elem,ER_NSONS(er))));
 
   FillOrderedSons(er,oco);
 
-  for (s=0; s<ER_NSONS(er); s++)
+  for (int s = 0; s < ER_NSONS(er); s++)
     key += oco[s];
 
   /** \todo (HRR 971211): use tag also for key? */
 
-  h = HASH_ADDRESS(key);
+  int h = HASH_ADDRESS(key);
 
-  hr = global.hash_table[h];
+  HRULE *hr = global.hash_table[h];
   if (hr==NULL)
     return (Hash_InsertRule(etag,key,er,oco,&(global.hash_table[h])));
 
@@ -575,7 +567,6 @@ static INT RuleCompare (int id, const URULE *ur, const ERULE *er)
 {
   const int ns0   = NSONS_OF_RULE(ur);
   const int ns1   = ER_NSONS(er);
-  int s0,s1;
 
   if (ns0!=ns1)
   {
@@ -584,12 +575,13 @@ static INT RuleCompare (int id, const URULE *ur, const ERULE *er)
   }
 
   /* compare sons */
-  for (s0=0; s0<ns0; s0++)
+  for (int s0 = 0; s0 < ns0; s0++)
   {
     const SONDATA *son0     = SON_OF_RULE(ur,s0);
     int nco0                        = CORNERS_OF_TAG(SON_TAG(son0));
 
-    for (s1=0; s1<ns1; s1++)
+    int s1;
+    for (s1 = 0; s1 < ns1; s1++)
     {
       int nco1 = ER_NCO(er,s1);
 
@@ -654,7 +646,6 @@ static INT ExtractERule (ELEMENT *elem, ERULE *er)
   int nsons = NSONS(elem);
   ELEMENT *sons[MAX_SONS];
   NODE *nodes[MAX_REFINED_CORNERS_DIM];
-  int s;
 
   if (GetNodeContext(elem,nodes))
     REP_ERR_RETURN(1);
@@ -664,12 +655,11 @@ static INT ExtractERule (ELEMENT *elem, ERULE *er)
     REP_ERR_RETURN(1);
 
   ER_NSONS(er) = 0;
-  for (s=0; s<nsons; s++)
+  for (int s = 0; s < nsons; s++)
   {
     ELEMENT *son = sons[s];
     int coe = CORNERS_OF_ELEM(son);
     SHORT corners[MAX_CORNERS_OF_ELEM_DIM];
-    int k,j;
 
     if (EGHOST(son)) continue;
 
@@ -677,11 +667,12 @@ static INT ExtractERule (ELEMENT *elem, ERULE *er)
 
     /* corners and dcorners */
     ER_NCO(er,s) = coe;
-    for (j=0; j<coe; j++)
+    for (int j = 0; j < coe; j++)
     {
-      NODE *node = CORNER(son,j);
+      const NODE *node = CORNER(son,j);
 
-      for (k=0; k<MAX_REFINED_CORNERS_DIM; k++)
+      int k;
+      for (k = 0; k < MAX_REFINED_CORNERS_DIM; k++)
         if (node==nodes[k])
           break;
       ASSERT(k<MAX_REFINED_CORNERS_DIM);
@@ -939,7 +930,7 @@ static int ExtractInterfaceERule (DDD::DDDContext&, DDD_OBJ obj)
 
   if (THEFLAG(elem))
   {
-    ERULE *er       = global.interface_rules+REFINE(elem);
+    const ERULE *er = global.interface_rules + REFINE(elem);
     int id          = GetRuleID(
                                                                 #ifdef Debug
       elem,
@@ -964,7 +955,7 @@ static int ExtractInterfaceERule (DDD::DDDContext&, DDD_OBJ obj)
     for (nsons=0; nsons<MAX_SONS; nsons++)
       if (sons[nsons]==NULL)
         break;
-    PrintDebug(ELEM_INFO("ExtractInterfaceERule",NO,elem,nsons));
+    PrintDebug(ELEM_INFO("ExtractInterfaceERule",false,elem,nsons));
     ENDDEBUG
   }
 
@@ -998,10 +989,8 @@ static INT ExtractInterfaceRules (MULTIGRID *mg)
   auto& context = mg->dddContext();
   const auto& dddctrl = ddd_ctrl(context);
 
-  int lev;
-
   /* TODO (HRR 971211): don't include TOPLEVEL (no elem refined there) */
-  for (lev=0; lev<=TOPLEVEL(mg); lev++)
+  for (int lev = 0; lev <= TOPLEVEL(mg); lev++)
   {
     GRID *grid = GRID_ON_LEVEL(mg,lev);
 
@@ -1040,10 +1029,9 @@ static INT ExtractInterfaceRules (MULTIGRID *mg)
 
       IFDEBUG(gm,ER_DBG_GENERAL)
       long N_er = 0;
-      int tag;
 
       PrintDebug("ExtractInterfaceRules: number of refrules extracted from interface on level %d:\n",lev);
-      for (tag=0; tag<TAGS; tag++)
+      for (int tag = 0; tag < TAGS; tag++)
       {
         long n_er = global.maxrule[tag] - UGMAXRULE(tag);
         N_er += n_er;
@@ -1085,11 +1073,9 @@ static INT ExtractInterfaceRules (MULTIGRID *mg)
 #if (defined UG_DIM_3) || (defined __DEBUG_ER__)
 static INT ExtractRules (MULTIGRID *mg)
 {
-  ELEMENT *elem;
   ERULE er;
-  HRID id;
   INT MarkKey;
-  int l,tag,h,maxrules;
+  int maxrules;
 
   /* for hash table */
   if (MarkTmpMem(global.heap,&MarkKey))
@@ -1099,22 +1085,22 @@ static INT ExtractRules (MULTIGRID *mg)
     REP_ERR_RETURN(1);
 
   global.nelems_inspected = global.nelems_not_inspected = 0;
-  for (tag=0; tag<TAGS; tag++)
+  for (int tag = 0; tag < TAGS; tag++)
     global.nelem_inspected[tag] = global.nelem_not_inspected[tag] = 0;
 
   /* loop elements and extract rules */
         #ifdef ModelP
   /* TODO (HRR 971211): don't include TOPLEVEL (no elem refined there) */
-  for (l=0; l<=TOPLEVEL(mg); l++)
-    for (elem=FIRSTELEMENT(GRID_ON_LEVEL(mg,l)); elem!=NULL; elem=SUCCE(elem))
+  for (int l = 0; l <= TOPLEVEL(mg); l++)
+    for (ELEMENT *elem = FIRSTELEMENT(GRID_ON_LEVEL(mg, l)); elem != NULL; elem = SUCCE(elem))
       SETUSED(elem,false);
   if (ExtractInterfaceRules(mg))
     REP_ERR_RETURN(1);
         #endif
 
   /* TODO (HRR 971211): don't include TOPLEVEL (no elem refined there) */
-  for (l=0; l<=TOPLEVEL(mg); l++)
-    for (elem=FIRSTELEMENT(GRID_ON_LEVEL(mg,l)); elem!=NULL; elem=SUCCE(elem))
+  for (int l = 0; l <= TOPLEVEL(mg); l++)
+    for (ELEMENT *elem = FIRSTELEMENT(GRID_ON_LEVEL(mg, l)); elem != NULL; elem = SUCCE(elem))
                         #ifdef ModelP
       if (!USED(elem))
       {
@@ -1123,7 +1109,7 @@ static INT ExtractRules (MULTIGRID *mg)
       {
         if (ExtractERule(elem,&er))
           REP_ERR_RETURN(1);
-        id = GetRuleID(
+        HRID id = GetRuleID(
                                                                 #ifdef Debug
           elem,
                                                                 #endif
@@ -1144,7 +1130,7 @@ static INT ExtractRules (MULTIGRID *mg)
         for (nsons=0; nsons<MAX_SONS; nsons++)
           if (sons[nsons]==NULL)
             break;
-        PrintDebug(ELEM_INFO("ExtractRules",NO,elem,nsons));
+        PrintDebug(ELEM_INFO("ExtractRules",false,elem,nsons));
         if (NSONS(elem)!=nsons)
           PrintDebug("------ ERROR: NSONS!=nsons -------\n");
         ENDDEBUG
@@ -1154,7 +1140,7 @@ static INT ExtractRules (MULTIGRID *mg)
 #endif
 
   global.maxrules = maxrules = 0;
-  for (tag=0; tag<TAGS; tag++)
+  for (int tag = 0; tag < TAGS; tag++)
   {
     global.maxrules += global.maxrule[tag];
     maxrules += global.maxrule[tag] - UGMAXRULE(tag);
@@ -1173,13 +1159,13 @@ static INT ExtractRules (MULTIGRID *mg)
     // In other words: it seems the method we are in is never called.
     global.hrule[0] = (HRULE**)
                       GetMemoryForObject(nullptr/*GetCurrentMultigrid()*/,
-                                         global.maxrules*sizeof(HRULE*),MAOBJ);
+                                         global.maxrules*sizeof(HRULE*),NOOBJ);
     if (global.hrule[0]==NULL)
       REP_ERR_RETURN(1);
-    for (tag=1; tag<TAGS; tag++)
+    for (int tag = 1; tag < TAGS; tag++)
       global.hrule[tag] = global.hrule[tag-1]+global.maxrule[tag-1];
 
-    for (h=0; h<HASH_SIZE; h++)
+    for (int h = 0; h < HASH_SIZE; h++)
     {
       int list_len = 0;
       HRULE *hr;
@@ -1231,26 +1217,23 @@ static INT ExtractRules (MULTIGRID *mg)
 
 static void FindPathForNeighbours (MGIO_RR_RULE *rule, SHORT myID, SHORT Status[MAX_SONS])
 {
-  SHORT i,nbID;
-
-  for (i=0; i<MAX_SIDES_OF_ELEM; i++)
-    if (((nbID=rule->sons[myID].nb[i])<FATHER_SIDE_OFFSET) && (Status[nbID]==NB_NOTDONE))
+  for (SHORT i = 0; i < MAX_SIDES_OF_ELEM; i++) {
+    SHORT nbID = rule->sons[myID].nb[i];
+    if ((nbID < FATHER_SIDE_OFFSET) && (Status[nbID] == NB_NOTDONE))
     {
-      INT nbPath;
-      SHORT nbPathDepth;
-
       /* copy myPath to nbPath */
-      nbPath = rule->sons[myID].path;
+      INT nbPath = rule->sons[myID].path;
 
       /* complete nbPath */
-      nbPathDepth = PATHDEPTH(nbPath);
+      SHORT nbPathDepth = PATHDEPTH(nbPath);
       SETNEXTSIDE(nbPath,nbPathDepth,i);
       SETPATHDEPTH(nbPath,++nbPathDepth);
       Status[nbID] = NB_TOUCHED;
     }
+  }
 
   /* recursive call for NB_TOUCHED sons */
-  for (nbID=1; nbID<rule->nsons; nbID++)
+  for (SHORT nbID = 1; nbID < rule->nsons; nbID++)
     if (Status[nbID]==NB_TOUCHED)
     {
       Status[nbID] = NB_DONE;
@@ -1280,7 +1263,6 @@ static void FindPathForNeighbours (MGIO_RR_RULE *rule, SHORT myID, SHORT Status[
 static void FillSonPaths (MGIO_RR_RULE *rule)
 {
   SHORT Status[MAX_SONS];
-  int i;
 
   /* TODO (HRR 971211): debug recursive path construction
      (taken from GenerateRules but not used by ugio) */
@@ -1288,7 +1270,7 @@ static void FillSonPaths (MGIO_RR_RULE *rule)
   /* son 0 has trivial path */
   Status[0] = NB_DONE;
   rule->sons[0].path = 0;
-  for (i=1; i<rule->nsons; i++)
+  for (int i = 1; i < rule->nsons; i++)
     Status[i] = NB_NOTDONE;
 
   /* start recursion with son 0 */
@@ -1313,34 +1295,33 @@ static void FillSonPaths (MGIO_RR_RULE *rule)
 
     RETURN VALUE:
     INT
-   .n   YES: ok, maybe there is a common father side
-   .n   NO:  sorry, center node definitely not on a father side
+   .n   true: ok, maybe there is a common father side
+   .n   false:  sorry, center node definitely not on a father side
    doctext_disabled*/
 /****************************************************************************/
 
-static INT GetFSidesOfCorners (int tag, int n, SHORT corners[MAX_CORNERS_OF_SIDE], SHORT corner_on_side[MAX_CORNERS_OF_SIDE][MAX_SIDES_OF_ELEM])
+static bool GetFSidesOfCorners (int tag, int n, const SHORT corners[MAX_CORNERS_OF_SIDE], SHORT corner_on_side[MAX_CORNERS_OF_SIDE][MAX_SIDES_OF_ELEM])
 {
   int coe = CORNERS_OF_TAG(tag);
   int eoe = EDGES_OF_TAG(tag);
   int soe = SIDES_OF_TAG(tag);
-  int co,side;
 
-  for (co=0; co<n; co++)
-    for (side=0; side<soe; side++)
+  for (int co = 0; co < n; co++)
+    for (int side = 0; side < soe; side++)
       corner_on_side[co][side] = false;
 
-  for (co=0; co<n; co++)
+  for (int co = 0; co < n; co++)
     if (corners[co]==coe+CENTER_NODE_INDEX_TAG(tag))
     {
       /* center node: can not be part of a father side */
-      return (NO);
+      return false;
     }
     else if (corners[co]<coe)
     {
       /* father corner */
       int fco = corners[co];
 
-      for (side=0; side<soe; side++)
+      for (int side = 0; side < soe; side++)
         if (CORNER_OF_SIDE_INV_TAG(tag,side,fco)>=0)
           corner_on_side[co][side] = true;
     }
@@ -1352,8 +1333,7 @@ static INT GetFSidesOfCorners (int tag, int n, SHORT corners[MAX_CORNERS_OF_SIDE
                         #ifdef UG_DIM_2
       corner_on_side[co][ed] = true;
                         #else
-      int i;
-      for (i=0; i<MAX_SIDES_OF_EDGE; i++)
+      for (int i = 0; i < MAX_SIDES_OF_EDGE; i++)
       {
         int sd = SIDE_WITH_EDGE_TAG(tag,ed,i);
         if (sd>=0)
@@ -1372,7 +1352,7 @@ static INT GetFSidesOfCorners (int tag, int n, SHORT corners[MAX_CORNERS_OF_SIDE
   else
     ASSERT(false);                              /* Huh??? */
 
-  return (YES);
+  return true;
 }
 
 /****************************************************************************/
@@ -1399,11 +1379,10 @@ static INT GetFSidesOfCorners (int tag, int n, SHORT corners[MAX_CORNERS_OF_SIDE
 
 static INT GetCommonFSide (int nco, int nsi, SHORT corner_on_side[MAX_CORNERS_OF_SIDE][MAX_SIDES_OF_ELEM])
 {
-  int i,side;
-
-  for (side=0; side<nsi; side++)
+  for (int side = 0; side < nsi; side++)
   {
-    for (i=0; i<nco; i++)
+    int i;
+    for (i = 0; i < nco; i++)
       if (!corner_on_side[i][side])
         break;
     if (i>=nco)
@@ -1430,12 +1409,12 @@ static INT GetCommonFSide (int nco, int nsi, SHORT corner_on_side[MAX_CORNERS_OF
 
     RETURN VALUE:
     INT
-   .n   YES: there is a  common father side
-   .n   NO:  there is no common father side
+   .n   true:  there is a  common father side
+   .n   false: there is no common father side
    doctext_disabled*/
 /****************************************************************************/
 
-static INT IsOnFatherSide (int tag, int nsco, SHORT sco[], SHORT *nb)
+static bool IsOnFatherSide (int tag, int nsco, SHORT sco[], SHORT *nb)
 {
   SHORT sco_on_side[MAX_CORNERS_OF_SIDE][MAX_SIDES_OF_ELEM];
 
@@ -1446,10 +1425,10 @@ static INT IsOnFatherSide (int tag, int nsco, SHORT sco[], SHORT *nb)
     if (fside<SIDES_OF_TAG(tag))
     {
       *nb = FATHER_SIDE_OFFSET+fside;
-      return (YES);
+      return true;
     }
   }
-  return (NO);
+  return false;
 }
 
 /****************************************************************************/
@@ -1469,31 +1448,28 @@ static INT IsOnFatherSide (int tag, int nsco, SHORT sco[], SHORT *nb)
 
     RETURN VALUE:
     INT
-   .n   YES: son sides are matching
-   .n   NO:  son sides are not matching
+   .n   true:  son sides are matching
+   .n   false: son sides are not matching
    doctext_disabled*/
 /****************************************************************************/
 
-static INT SidesMatch (int nsco, SHORT sco0[], SHORT sco1[])
+static bool SidesMatch (int nsco, const SHORT sco0[], const SHORT sco1[])
 {
-  int i;
-
   /* try each permutation of first with reverse order of second */
-  for (i=0; i<nsco; i++)
+  for (int i = 0; i < nsco; i++)
   {
     int match = true;
-    int j;
 
-    for (j=0; j<nsco; j++)
+    for (int j = 0; j < nsco; j++)
       if (sco0[(i+j)%nsco]!=sco1[nsco-j-1])
       {
         match = false;
         break;
       }
     if (match)
-      return (YES);
+      return true;
   }
-  return (NO);
+  return false;
 }
 
 /****************************************************************************/
@@ -1519,18 +1495,17 @@ static INT SidesMatch (int nsco, SHORT sco0[], SHORT sco1[])
 static void HRule2Mrule (const HRULE *hr, MGIO_RR_RULE *mr)
 {
   int coe = CORNERS_OF_TAG(HR_TAG(hr));
-  int s,s0;
 
   /* extracted rules are always irregular */
   /* TODO (HRR 971208): is that really ok (actually not used)? */
   mr->rclass = GREEN_CLASS;
   mr->nsons = HR_NSONS(hr);
 
-  {int i; for (i=0; i<MGIO_MAX_NEW_CORNERS; i++)
-     mr->pattern[i] = 0;}
+  for (int i = 0; i < MGIO_MAX_NEW_CORNERS; i++)
+     mr->pattern[i] = 0;
 
   /* son tags, corners, sonandnode, pattern */
-  for (s=0; s<mr->nsons; s++)
+  for (int s = 0; s < mr->nsons; s++)
   {
     struct mgio_sondata *sonData = &(mr->sons[s]);
     int nco = HR_NCO(hr,s);
@@ -1557,33 +1532,30 @@ static void HRule2Mrule (const HRULE *hr, MGIO_RR_RULE *mr)
   }
 
   /* son nb */
-  for (s0=0; s0<mr->nsons; s0++)
+  for (int s0 = 0; s0 < mr->nsons; s0++)
   {
     struct mgio_sondata *sonData0 = mr->sons+s0;
-    int sd0;
 
-    for (sd0=0; sd0<MAX_SIDES_OF_ELEM; sd0++)
+    for (int sd0 = 0; sd0 < MAX_SIDES_OF_ELEM; sd0++)
       if (sonData0->nb[sd0] == NOTDONE)
       {
         int stag0 = sonData0->tag;
         int nsco0 = CORNERS_OF_SIDE_TAG(stag0,sd0);
         SHORT sco0[MAX_CORNERS_OF_SIDE];
 
-        {int j; for (j=0; j<nsco0; j++)
-           sco0[j] = sonData0->corners[CORNER_OF_SIDE_TAG(stag0,sd0,j)];}
+        for (int j = 0; j < nsco0; j++)
+           sco0[j] = sonData0->corners[CORNER_OF_SIDE_TAG(stag0,sd0,j)];
 
         if (!IsOnFatherSide(HR_TAG(hr),nsco0,sco0,&(sonData0->nb[sd0])))
         {
-          int found = NO;
-          int s1;
+          bool found = false;
 
           /* find matching side of other son */
-          for (s1=s0+1; s1<mr->nsons; s1++)
+          for (int s1 = s0+1; s1 < mr->nsons; s1++)
           {
             struct mgio_sondata *sonData1 = mr->sons+s1;
-            int sd1;
 
-            for (sd1=0; sd1<MAX_SIDES_OF_ELEM; sd1++)
+            for (int sd1 = 0; sd1 < MAX_SIDES_OF_ELEM; sd1++)
             {
               int stag1 = sonData1->tag;
               int nsco1 = CORNERS_OF_SIDE_TAG(stag1,sd1);
@@ -1601,7 +1573,7 @@ static void HRule2Mrule (const HRULE *hr, MGIO_RR_RULE *mr)
                   sonData0->nb[sd0] = s1;
                   sonData1->nb[sd1] = s0;
 
-                  found = YES;
+                  found = true;
                   break;
                 }
               }
@@ -1643,25 +1615,23 @@ static void HRule2Mrule (const HRULE *hr, MGIO_RR_RULE *mr)
 
 static void URule2Mrule (const URULE *ur, MGIO_RR_RULE *mr)
 {
-  int j,k;
-
   mr->rclass = ur->rclass;
   mr->nsons = ur->nsons;
-  for (j=0; j<MGIO_MAX_NEW_CORNERS; j++)
+  for (int j = 0; j < MGIO_MAX_NEW_CORNERS; j++)
     mr->pattern[j] = ur->pattern[j];
-  for (j=0; j<MGIO_MAX_NEW_CORNERS; j++)
+  for (int j = 0; j < MGIO_MAX_NEW_CORNERS; j++)
   {
     mr->sonandnode[j][0] = ur->sonandnode[j][0];
     mr->sonandnode[j][1] = ur->sonandnode[j][1];
   }
-  for (j=0; j<mr->nsons; j++)
+  for (int j = 0; j < mr->nsons; j++)
   {
     struct mgio_sondata *sonData = &(mr->sons[j]);
 
     sonData->tag = ur->sons[j].tag;
-    for (k=0; k<MGIO_MAX_CORNERS_OF_ELEM; k++)
+    for (int k = 0; k < MGIO_MAX_CORNERS_OF_ELEM; k++)
       sonData->corners[k] = ur->sons[j].corners[k];
-    for (k=0; k<MGIO_MAX_SIDES_OF_ELEM; k++)
+    for (int k = 0; k < MGIO_MAX_SIDES_OF_ELEM; k++)
       sonData->nb[k] = ur->sons[j].nb[k];
     sonData->path = ur->sons[j].path;
   }
@@ -1670,17 +1640,20 @@ static void URule2Mrule (const URULE *ur, MGIO_RR_RULE *mr)
 static void WriteDebugInfo (void)
 {
   long N_rm=0,N_er=0;
-  int tag;
+  long Nelem_inspected = 0;
+  long Nelem_not_inspected = 0;
 
   /* number of rules (rm+er) */
   PrintDebug("------------- Write_RefRules statistics --------------\n");
   PrintDebug("number of refrules:\n");
-  for (tag=0; tag<TAGS; tag++)
+  for (int tag = 0; tag < TAGS; tag++)
   {
     long n_rm = UGMAXRULE(tag);
     long n_er = global.maxrule[tag]-UGMAXRULE(tag);
     N_rm += n_rm;
     N_er += n_er;
+    Nelem_inspected = global.nelem_inspected[tag];
+    Nelem_not_inspected += global.nelem_not_inspected[tag];
     PrintDebug("tag %d: %3ld rm rules, %4ld extracted rules (elems inspected: %6ld yes %6ld no)\n",
                tag,
                n_rm,
@@ -1691,25 +1664,23 @@ static void WriteDebugInfo (void)
   PrintDebug("total: %3ld rm rules, %4ld extracted rules (elems inspected: %6ld yes %6ld no)\n",
              N_rm,
              N_er,
-             global.nelem_inspected[tag],
-             global.nelem_not_inspected[tag]);
+             Nelem_inspected,
+             Nelem_not_inspected);
 
   PrintDebug("------------------------------------------------------\n");
 }
 
 INT NS_DIM_PREFIX GetOrderedSons (ELEMENT *theElement, MGIO_RR_RULE *theRule, NODE **NodeContext, ELEMENT **SonList, INT *nmax)
 {
-  INT i,j,k,l,found;
   ELEMENT *NonorderedSonList[MAX_SONS];
-  NODE *theNode;
 
   *nmax = 0;
 
   if (GetAllSons(theElement,NonorderedSonList)) REP_ERR_RETURN(1);
-  for (i=0; i<theRule->nsons; i++)
+  for (INT i = 0; i < theRule->nsons; i++)
   {
-    found=1;
-    for (j=0; j<CORNERS_OF_TAG(theRule->sons[i].tag); j++)
+    INT found = 1;
+    for (INT j = 0; j < CORNERS_OF_TAG(theRule->sons[i].tag); j++)
       if (NodeContext[theRule->sons[i].corners[j]] == NULL)
       {
         found=0;
@@ -1722,13 +1693,13 @@ INT NS_DIM_PREFIX GetOrderedSons (ELEMENT *theElement, MGIO_RR_RULE *theRule, NO
     }
 
     /* identify (hopefully) an element of SonList */
-    for (j=0; NonorderedSonList[j]!=NULL; j++)
+    for (INT j = 0; NonorderedSonList[j] != NULL; j++)
     {
       found=0;
-      for (l=0; l<CORNERS_OF_TAG(theRule->sons[i].tag); l++)
+      for (INT l = 0; l < CORNERS_OF_TAG(theRule->sons[i].tag); l++)
       {
-        theNode = NodeContext[theRule->sons[i].corners[l]];
-        for (k=0; k<CORNERS_OF_ELEM(NonorderedSonList[j]); k++)
+        const NODE *theNode = NodeContext[theRule->sons[i].corners[l]];
+        for (INT k = 0; k < CORNERS_OF_ELEM(NonorderedSonList[j]); k++)
           if (theNode==CORNER(NonorderedSonList[j],k))
           {
             found++;
@@ -1749,24 +1720,22 @@ INT NS_DIM_PREFIX GetOrderedSons (ELEMENT *theElement, MGIO_RR_RULE *theRule, NO
   return (0);
 }
 
-static int CheckNBrelations (MGIO_RR_RULE *mr, int i, int tag)
+static int CheckNBrelations (MGIO_RR_RULE *mr, int rule, int tag)
 {
   int n = mr->nsons;
   int err=0;
-  int s;
 
-  for (s=0; s<n; s++)
+  for (int s = 0; s < n; s++)
   {
     struct mgio_sondata *son = &(mr->sons[s]);
     int ns = SIDES_OF_TAG(son->tag);
-    int i;
 
-    for (i=0; i<ns; i++)
+    for (int i = 0; i < ns; i++)
     {
       int nb = son->nb[i];
       if (nb<FATHER_SIDE_OFFSET)
       {
-        struct mgio_sondata *nbson = &(mr->sons[nb]);
+        const struct mgio_sondata *nbson = &(mr->sons[nb]);
         int nnbs = SIDES_OF_TAG(nbson->tag);
         int j;
 
@@ -1775,7 +1744,7 @@ static int CheckNBrelations (MGIO_RR_RULE *mr, int i, int tag)
             break;
         if (j>=nnbs)
         {
-          PrintDebug("ERROR: rule %d of %d, asym in son %d, nb %d\n",i,tag,s,i);
+          PrintDebug("ERROR: rule %d of %d, asym in son %d, nb %d\n",rule,tag,s,i);
           err++;
         }
       }
@@ -1786,13 +1755,10 @@ static int CheckNBrelations (MGIO_RR_RULE *mr, int i, int tag)
 
 static void CheckMRules (MULTIGRID *mg, INT RefRuleOffset[], MGIO_RR_RULE *mrules)
 {
-  ELEMENT *elem;
-  int l;
   int max_path_depth = 0;
   int use_bug_in_rule = true;
   short *bug_in_rule[TAGS];
   INT MarkKey;
-  int tg;
 
   if (MarkTmpMem(global.heap,&MarkKey))
     use_bug_in_rule = false;
@@ -1803,28 +1769,26 @@ static void CheckMRules (MULTIGRID *mg, INT RefRuleOffset[], MGIO_RR_RULE *mrule
       use_bug_in_rule = false;
     else
     {
-      int t,i;
-      for (t=0; t<TAGS; t++)
+      for (int t = 0; t < TAGS; t++)
       {
         bug_in_rule[t] = bug_in_rule[0] + RefRuleOffset[t];
-        for (i=0; i<global.maxrule[t]; i++)
+        for (int i = 0; i < global.maxrule[t]; i++)
           bug_in_rule[t][i] = false;
       }
     }
   }
 
   /* check symmetry of nb relations */
-  for (tg=0; tg<TAGS; tg++)
+  for (int tg = 0; tg < TAGS; tg++)
   {
-    int i;
-    for (i=0; i<global.maxrule[tg]; i++)
+    for (int i = 0; i < global.maxrule[tg]; i++)
       if (CheckNBrelations(mrules+RefRuleOffset[tg]+i,i,tg))
         if (use_bug_in_rule)
           bug_in_rule[tg][i] = true;
   }
 
-  for (l=0; l<TOPLEVEL(mg); l++)
-    for (elem=PFIRSTELEMENT(GRID_ON_LEVEL(mg,l)); elem!=NULL; elem=SUCCE(elem))
+  for (int l = 0; l < TOPLEVEL(mg); l++)
+    for (ELEMENT *elem = PFIRSTELEMENT(GRID_ON_LEVEL(mg,l )); elem != NULL; elem = SUCCE(elem))
       if (NSONS(elem)>0)
       {
         int refi                        = REFINE(elem);
@@ -1839,7 +1803,6 @@ static void CheckMRules (MULTIGRID *mg, INT RefRuleOffset[], MGIO_RR_RULE *mrule
         INT maxsonex            = 0;
         ELEMENT *sons[MAX_SONS];
         int error = 0;
-        int s,i;
 
         /* check nsons */
         if (NSONS(elem)!=nsons)
@@ -1849,7 +1812,7 @@ static void CheckMRules (MULTIGRID *mg, INT RefRuleOffset[], MGIO_RR_RULE *mrule
           ASSERT(false);
 
         /* check pattern */
-        for (i=0; i<MAX_NEW_CORNERS_DIM; i++)
+        for (int i = 0; i < MAX_NEW_CORNERS_DIM; i++)
           if (mr->pattern[i])
           {
                                                 #ifndef ModelP
@@ -1870,7 +1833,7 @@ static void CheckMRules (MULTIGRID *mg, INT RefRuleOffset[], MGIO_RR_RULE *mrule
         if (maxsonex!=nsons)
           PD_ERR(ER_DBG_RULE_VERBOSE,("ERROR in CheckMRules, elem %ld: wrong number of sons (%d vs %d)\n",id,maxsonex,nsons),error);
                                 #endif
-        for (s=0; s<maxsonex; s++)
+        for (int s = 0; s < maxsonex; s++)
         {
           ELEMENT *son = sons[s];
           if (son!=NULL)
@@ -1878,23 +1841,22 @@ static void CheckMRules (MULTIGRID *mg, INT RefRuleOffset[], MGIO_RR_RULE *mrule
             struct mgio_sondata *rson = &(mr->sons[s]);
             int nco = CORNERS_OF_ELEM(son);
             int nsi = SIDES_OF_ELEM(son);
-            int co,si;
 
             if (rson->tag!=TAG(son))
               PD_ERR(ER_DBG_RULE_VERBOSE,("ERROR in CheckMRules, elem %ld: wrong tag of son %d (%d vs %d)\n",id,s,rson->tag,TAG(son)),error);
 
             /* check corners */
-            for (co=0; co<nco; co++)
+            for (int co = 0; co < nco; co++)
               if (CORNER(son,co)!=nodes[rson->corners[co]])
                 PD_ERR(ER_DBG_RULE_VERBOSE,("ERROR in CheckMRules, elem %ld: corner %d of son %d inconsistent\n",id,co,s),error);
 
             /* check neighbours */
-            for (si=0; si<nsi; si++)
+            for (int si = 0; si < nsi; si++)
             {
-              ELEMENT *nb = NBELEM(son,si);
+              const ELEMENT *nb = NBELEM(son,si);
               if (nb!=NULL)
               {
-                ELEMENT *nbf = EFATHER(nb);
+                const ELEMENT *nbf = EFATHER(nb);
 
                 if (nbf==elem)
                 {
@@ -1991,12 +1953,10 @@ static void CheckMRules (MULTIGRID *mg, INT RefRuleOffset[], MGIO_RR_RULE *mrule
 
   if (use_bug_in_rule)
   {
-    int t,i;
-
     PrintDebug("--------------- CheckMRules: rules with bugs ---------------\n");
 
-    for (t=0; t<TAGS; t++)
-      for (i=0; i<global.maxrule[t]; i++)
+    for (int t = 0; t < TAGS; t++)
+      for (int i = 0; i < global.maxrule[t]; i++)
         if (bug_in_rule[t][i])
         {
           PrintDebug("-- rule %4d of %d\n",i,t);
@@ -2044,7 +2004,6 @@ INT NS_DIM_PREFIX NEW_Write_RefRules (MULTIGRID *mg, INT RefRuleOffset[], INT Ma
   MGIO_RR_GENERAL rr_general;
   MGIO_RR_RULE *mrule;
   INT BotMarkKey;
-  int tag;
 
   if (mg==NULL)
     REP_ERR_RETURN(1);
@@ -2056,7 +2015,7 @@ INT NS_DIM_PREFIX NEW_Write_RefRules (MULTIGRID *mg, INT RefRuleOffset[], INT Ma
   /* init rule counters (continue with last rule IDs of rm) */
   /* TODO (HRR 971207): this is important for matching existing rules after loading a grid (coarsening)
                                             but CAUTION: refine should never address a rule beyond rm rules! */
-  for (tag=0; tag<TAGS; tag++)
+  for (int tag = 0; tag < TAGS; tag++)
     global.maxrule[tag] = UGMAXRULE(tag);
 
         #if (defined UG_DIM_3) || (defined __DEBUG_ER__)
@@ -2066,12 +2025,12 @@ INT NS_DIM_PREFIX NEW_Write_RefRules (MULTIGRID *mg, INT RefRuleOffset[], INT Ma
         #endif
 
   global.maxrules = 0;
-  for (tag=0; tag<TAGS; tag++)
+  for (int tag = 0; tag < TAGS; tag++)
     global.maxrules += global.maxrule[tag];
 
   /* write refrules general */
   RefRuleOffset[0] = 0;
-  for (tag=0; tag<TAGS; tag++)
+  for (int tag = 0; tag < TAGS; tag++)
   {
     if (tag>0) RefRuleOffset[tag] = RefRuleOffset[tag-1] + global.maxrule[tag-1];
     rr_general.RefRuleOffset[tag] = RefRuleOffset[tag];
@@ -2087,7 +2046,7 @@ INT NS_DIM_PREFIX NEW_Write_RefRules (MULTIGRID *mg, INT RefRuleOffset[], INT Ma
 
   /* write refrules */
   mrule = *mrule_handle;
-  for (tag=0; tag<TAGS; tag++)
+  for (int tag = 0; tag < TAGS; tag++)
   {
     int i;
 
@@ -2146,14 +2105,13 @@ INT NS_DIM_PREFIX NEW_Write_RefRules (MULTIGRID *mg, INT RefRuleOffset[], INT Ma
 
 INT NS_DIM_PREFIX ResetRefineTagsBeyondRuleManager (MULTIGRID *mg)
 {
-  ELEMENT *elem;
 #ifdef Debug
   int n = 0;
 #endif
 
   /** \todo (HRR 971211): don't include TOPLEVEL (no elem refined there) */
   for (int l=0; l<=TOPLEVEL(mg); l++)
-    for (elem=PFIRSTELEMENT(GRID_ON_LEVEL(mg,l)); elem!=NULL; elem=SUCCE(elem))
+    for (ELEMENT *elem = PFIRSTELEMENT(GRID_ON_LEVEL(mg, l)); elem != NULL; elem = SUCCE(elem))
       if (BEYOND_UG_RULES(elem))
       {
         SETREFINE(elem,COPY);
