@@ -60,28 +60,6 @@ START_UGDIM_NAMESPACE
 /****************************************************************************/
 
 
-/* space dimension indices */
-#define _X_             0
-#define _Y_             1
-#define _Z_             2
-
-/* misc macros */
-#define SQRT(a)                                 sqrt((double)(a))
-#define POW(a,b)                                pow((double)(a),(double)(b))
-#define ISNaN(x)                                (!((x)-(x)==0) || ((x)-(x)!=0))
-
-/* macros for coord points */
-#define COPY_SC_TO_SH(p1,p2)                    (p2).x=(short)((p1).x);(p2).y=(short)((p1).y)
-#define CP_SUBTRACT(A,B,C)                      {(C).x = (A).x - (B).x;\
-                                                 (C).y = (A).y - (B).y;}
-#define CP_LIMCOMB(a,A,b,B,C)                   {(C).x = (DOUBLE)(a)*(A).x + (DOUBLE)(b)*(B).x;\
-                                                 (C).y = (DOUBLE)(a)*(A).y + (DOUBLE)(b)*(B).y;}
-#define CP_SCALARPRODUCT(A,B,c)                  (c) = (A).x*(B).x + (A).y*(B).y;
-#define CP_EUKLIDNORM(A,b)                       (b) = (DOUBLE)sqrt((double)((A).x*(A).x+(A).y*(A).y));
-
-/* macros for 1D vector operations */
-#define V1_COPY(A,C)                            {(C)[0] = (A)[0];}
-
 /* macros for 2D vector operations */
 #define V2_LINCOMB(a,A,b,B,C)              {(C)[0] = (a)*(A)[0] + (b)*(B)[0];\
                                             (C)[1] = (a)*(A)[1] + (b)*(B)[1];}
@@ -199,8 +177,6 @@ START_UGDIM_NAMESPACE
 
 #ifdef UG_DIM_2
 
-#define V_BDIM_COPY(A,C)                        V1_COPY(A,C)
-
 #define V_DIM_LINCOMB(a,A,b,B,C)                V2_LINCOMB(a,A,b,B,C)
 #define V_DIM_COPY(A,C)                         V2_COPY(A,C)
 #define V_DIM_SUBTRACT(A,B,C)                   V2_SUBTRACT(A,B,C)
@@ -220,8 +196,6 @@ START_UGDIM_NAMESPACE
 
 #ifdef UG_DIM_3
 
-#define V_BDIM_COPY(A,C)                        V2_COPY(A,C)
-
 #define V_DIM_LINCOMB(a,A,b,B,C)                V3_LINCOMB(a,A,b,B,C)
 #define V_DIM_COPY(A,C)                         V3_COPY(A,C)
 #define V_DIM_SUBTRACT(A,B,C)                   V3_SUBTRACT(A,B,C)
@@ -239,27 +213,6 @@ START_UGDIM_NAMESPACE
 
 #endif
 
-/****************************************************************************/
-/*                                                                          */
-/* typedef of 2d points for screen coordinates                              */
-/*                                                                          */
-/****************************************************************************/
-
-struct coord_point
-{
-  DOUBLE x;
-  DOUBLE y;
-};
-
-typedef struct coord_point COORD_POINT;
-
-/****************************************************************************/
-/*                                                                          */
-/* definition of exported global variables                                  */
-/*                                                                          */
-/****************************************************************************/
-
-extern const DOUBLE unit_vec[DIM][DIM];
 
 /****************************************************************************/
 /*                                                                          */
@@ -267,12 +220,8 @@ extern const DOUBLE unit_vec[DIM][DIM];
 /*                                                                          */
 /****************************************************************************/
 
-/* general routines */
-bool            PointInPolygon                                          (const COORD_POINT *Points, INT n, COORD_POINT Point);
-
 /* 2D routines */
 DOUBLE          vp                                                                      (const DOUBLE x1, const DOUBLE y1, const DOUBLE x2, const DOUBLE y2);
-INT             V2_Normalize                                            (DOUBLE *a);
 DOUBLE          c_tarea                                                         (const DOUBLE *x0, const DOUBLE *x1, const DOUBLE *x2);
 DOUBLE          c_qarea                                                         (const DOUBLE *x0, const DOUBLE *x1, const DOUBLE *x2, const DOUBLE *x3);
 DOUBLE          V_te                                                            (const DOUBLE *x0, const DOUBLE *x1,
@@ -287,8 +236,7 @@ DOUBLE          V_he
 
 /* 3D routines */
 INT             M3_Invert                                                       (DOUBLE *Inverse, const DOUBLE *Matrix);
-INT             V3_Normalize                                            (DOUBLE *a);
-INT             V3_Project                                                      (const DOUBLE *a, const DOUBLE *b, DOUBLE *r);
+INT             V3_Normalize                                                    (FieldVector<DOUBLE,3>& a);
 
 
 /* volume calculations*/
