@@ -47,7 +47,6 @@
 #include <dune/uggrid/low/heaps.h>
 #include <dune/uggrid/low/misc.h>
 #include <dune/uggrid/low/ugenv.h>
-#include <dune/uggrid/low/ugstruct.h>
 #include <dune/uggrid/low/ugtypes.h>
 
 #include <dune/uggrid/ugdevices.h>
@@ -92,7 +91,11 @@ using namespace PPIF;
 /*																			*/
 /****************************************************************************/
 
+#ifdef ModelP
+#if defined(UG_DIM_2)
 static DOUBLE hghost_overlap = 1.0;
+#endif
+#endif
 
 /****************************************************************************/
 /*                                                                          */
@@ -105,7 +108,7 @@ static INT CheckVertex (ELEMENT *theElement, NODE* theNode, VERTEX *theVertex)
   ELEMENT *theFather = VFATHER(theVertex);
   EDGE    *theEdge;
   INT i,nerrors,n;
-  DOUBLE  *global,*local,diff;
+  DOUBLE diff;
   DOUBLE_VECTOR global1;
   DOUBLE *x[MAX_CORNERS_OF_ELEM];
 
@@ -167,8 +170,8 @@ static INT CheckVertex (ELEMENT *theElement, NODE* theNode, VERTEX *theVertex)
 
   if (theFather != NULL) {
     CORNER_COORDINATES(theFather,n,x);
-    global = CVECT(theVertex);
-    local = LCVECT(theVertex);
+    const Dune::FieldVector<DOUBLE,DIM>& global = CVECT(theVertex);
+    const Dune::FieldVector<DOUBLE,DIM>& local = LCVECT(theVertex);
     LOCAL_TO_GLOBAL(n,x,local,global1);
     V_DIM_EUKLIDNORM_OF_DIFF(global1,global,diff);
     if (diff > MAX_PAR_DIST) {
@@ -359,13 +362,12 @@ static INT CheckNode (ELEMENT *theElement, NODE* theNode, INT i)
       UserWriteF(" elem=" EID_FMTX, EID_PRTX(theElement));
       if (EFATHER(theElement) != NULL)
       {
-        INT i;
         ELEMENT *theFather = EFATHER(theElement);
 
         UserWriteF(" father=" EID_FMTX "\n",EID_PRTX(theFather));
-        for (i=0; i<CORNERS_OF_ELEM(theFather); i++)
+        for (int j=0; j < CORNERS_OF_ELEM(theFather); j++)
         {
-          UserWriteF("son[%d]=" ID_FMTX "\n",i,ID_PRTX(CORNER(theFather,i)));
+          UserWriteF("son[%d]=" ID_FMTX "\n",j,ID_PRTX(CORNER(theFather,j)));
         }
       }
       else
@@ -1109,7 +1111,7 @@ static INT CheckElement (GRID *theGrid, ELEMENT *theElement, INT *SideError, INT
 
 #if defined(UG_DIM_2) || defined(ModelP)
 
-INT CheckSubdomains (MULTIGRID *theMG)
+INT CheckSubdomains (const MULTIGRID *theMG)
 {
   return (0);
 }
@@ -1497,17 +1499,16 @@ static INT CheckGeometry (GRID *theGrid)
                      ECLASS(theElement),EID_PRTX(EFATHER(theElement)),
                      ECLASS(EFATHER(theElement)),REFINE(EFATHER(theElement)));
           {
-            INT i;
             ELEMENT *theFather = EFATHER(theElement);
             ELEMENT *theNeighbor;
 
-            for (i=0; i<SIDES_OF_ELEM(theFather); i++)
+            for (int k=0; k < SIDES_OF_ELEM(theFather); k++)
             {
-              theNeighbor = NBELEM(theFather,i);
+              theNeighbor = NBELEM(theFather,k);
               if (theNeighbor != NULL)
               {
                 UserWriteF("NB[%d]=" EID_FMTX " NBREFINE=%d\n",
-                           i,EID_PRTX(theNeighbor),REFINE(theNeighbor));
+                           k,EID_PRTX(theNeighbor),REFINE(theNeighbor));
 
               }
             }
@@ -1654,14 +1655,8 @@ static INT CheckGeometry (GRID *theGrid)
   {
     if (!USED(theNode))
     {
-#if defined  __OVERLAP2__
-      IFDEBUG(np,1)
-      UserWriteF("Info: node=" ID_FMTX " has no element\n",ID_PRTX(theNode));
-      ENDDEBUG
-#else
       errors++;
       UserWriteF("node=" ID_FMTX " is dead\n",ID_PRTX(theNode));
-#endif
     }
     else
       SETUSED(theNode,0);
@@ -1730,7 +1725,7 @@ static INT CheckGeometry (GRID *theGrid)
   return(errors);
 }
 
-static INT CheckElementList (GRID *theGrid)
+static INT CheckElementList (const GRID *theGrid)
 {
   ELEMENT *theElement;
 
@@ -1823,9 +1818,6 @@ INT NS_DIM_PREFIX CheckGrid (GRID *theGrid, INT checkgeom, INT checkalgebra, INT
   INT errors              = 0;
   INT totalerrors = 0;
 
-  if (GetStringValue(":conf:hghost_overlap",&hghost_overlap) !=0)
-    UserWriteF("CheckGrid: warning %s not set\n",":conf:hghost_overlap");
-
   /* check geometrical data structures */
   if (checkgeom)
   {
