@@ -1,5 +1,7 @@
 // -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 // vi: set et ts=4 sw=2 sts=2:
+// SPDX-FileCopyrightInfo: Copyright © DUNE Project contributors, see file LICENSE.md in module root
+// SPDX-License-Identifier: LGPL-2.1-or-later
 /*! \file rm.h
  * \ingroup gm
  */
@@ -341,7 +343,7 @@ INT                     InitRuleManager                 (void);
 INT                     Patterns2Rules                  (ELEMENT *theElement,INT pattern);
 ELEMENT         *ELEMENT_TO_MARK                (ELEMENT *theElement);
 
-#ifdef __THREEDIM__
+#ifdef UG_DIM_3
 INT             GetRule_AnisotropicRed  (ELEMENT *theElement, INT *Rule);
 #endif
 
