@@ -29,6 +29,7 @@
 /****************************************************************************/
 
 #include <config.h>
+#include <array>
 #include <cstdlib>
 #include <cstring>
 #include <cstdio>
@@ -63,7 +64,7 @@ USING_UG_NAMESPACE
 /** \brief Path to current directory
 
    We only need the first entry to be zero-initialized. */
-static ENVDIR *path[MAXENVPATH] = {NULL};
+static std::array<ENVDIR*, MAXENVPATH> path{nullptr};
 static int pathIndex;                   /* entry to path array              */
 
 
@@ -119,7 +120,7 @@ INT NS_PREFIX InitUgEnv ()
 
 ENVDIR * NS_PREFIX ChangeEnvDir (const char *s)
 {
-  ENVDIR *newPath[MAXENVPATH];
+  std::array<ENVDIR*, MAXENVPATH> newPath;
   ENVDIR *theDir;
   INT i,k,len;
   char token[NAMESIZE];
@@ -379,9 +380,7 @@ INT NS_PREFIX RemoveEnvItem (ENVITEM *theItem)
   return(0);
 }
 
-#ifndef __T3E__
 static
-#endif
 INT RemoveEnvDirContent (ENVITEM *theItem)
 {
   ENVITEM *Item,*Next;
@@ -570,38 +569,6 @@ ENVITEM * NS_PREFIX SearchEnv (const char *name, const char *where, INT type, IN
   return(SearchTree(name,type,dirtype));
 }
 
-
-/****************************************************************************/
-/** \brief For backward compatibility: Allocate memory from environment heap
-
- * @param   size - number of bytes to be allocated
-
-   \deprecated Simply a wrapper for malloc()
-
-   @return <ul>
-   Pointer to allocated memory
- */
-/****************************************************************************/
-
-void * NS_PREFIX AllocEnvMemory (INT size)
-{
-  return malloc(size);
-}
-
-/****************************************************************************/
-/** \brief For backward compatibility: Deallocate memory from environment heap
-
- * @param   buffer - pointer to buffer previously allocated
-
-   \deprecated Simply a wrapper for free()
- */
-/****************************************************************************/
-
-void NS_PREFIX FreeEnvMemory (void *buffer)
-{
-  free(buffer);
-}
-
 /****************************************************************************/
 /** \brief For backward compatibility: Print size and used of environment heap to string
 
