@@ -1,5 +1,7 @@
 // -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 // vi: set et ts=4 sw=2 sts=2:
+// SPDX-FileCopyrightInfo: Copyright © DUNE Project contributors, see file LICENSE.md in module root
+// SPDX-License-Identifier: LGPL-2.1-or-later
 
 /** \file
     \brief Globally set data types
@@ -7,8 +9,7 @@
     The basic types (normally 'short', 'int', 'float' and 'double') are
     replaced by 'SHORT', 'INT', 'FLOAT' and 'DOUBLE'. The type 'DOUBLE'
     is used for all Cartesian coordinates of the (x,y[,z])-directions of
-    the grids and 'SCREEN_DOUBLE' is used for all transformed coordinates
-    of the graphical interface.
+    the grids.
  */
 
 #ifndef UGTYPES_H
@@ -29,8 +30,6 @@ typedef unsigned int UINT;
 
 typedef float FLOAT;
 typedef double DOUBLE;
-typedef float COORD;
-typedef float SCREEN_COORD;
 
 END_UG_NAMESPACE
 
