@@ -238,16 +238,12 @@ static void VectorXferCopy(DDD::DDDContext& context, DDD_OBJ obj, DDD_PROC proc,
   INT flag;
 
   PRINTDEBUG(dddif,1,(PFMT " VectorXferCopy(): v=" VINDEX_FMTX " proc=%d "
-                      "prio=%d vtype=%d\n",me,VINDEX_PRTX(pv),proc,prio,VTYPE(pv)))
+                      "prio=%d\n",me,VINDEX_PRTX(pv),proc,prio))
 
-#if defined __OVERLAP2__
-  flag = 1;             /* for overlap 2 ghost-matrices are required too */
-#else
   flag = (!GHOSTPRIO(prio));
     #ifndef __EXCHANGE_CONNECTIONS__
   flag = (flag && (level < 0));
         #endif
-#endif
 
   /*
           else
@@ -496,7 +492,9 @@ static void NodeObjInit(DDD::DDDContext&, DDD_OBJ obj)
 
 static void NodeObjMkCons (DDD::DDDContext& context, DDD_OBJ obj, int newness)
 {
+#if defined(Debug) || defined(TOPNODE) || defined(UG_DIM_2)
   NODE *theNode   = (NODE *) obj;
+#endif
 
   PRINTDEBUG(dddif,2,(PFMT " NodeObjMkCons(): n=" ID_FMTX " NDOBJ=%d\n",
                       me,ID_PRTX(theNode),OBJT(theNode)))
@@ -852,9 +850,7 @@ static void ElementXferCopy (DDD::DDDContext& context, DDD_OBJ obj, DDD_PROC pro
   auto& dddctrl = ddd_ctrl(context);
 
   INT i,nsides;
-  INT Size;
   ELEMENT *pe     =       (ELEMENT *)obj;
-  VECTOR  *vec;
   NODE    *node;
   BNDS    *bnds[MAX_SIDES_OF_ELEM];
 
@@ -920,7 +916,11 @@ static void ElementXferCopy (DDD::DDDContext& context, DDD_OBJ obj, DDD_PROC pro
       VECTOR *vec = EDVECTOR(edge);
 
       if (vec != NULL) {
-        int Size = sizeof(VECTOR)-sizeof(DOUBLE) + FMT_S_VEC_TP;
+#ifdef UG_DIM_2
+        int Size = sizeof(VECTOR)-sizeof(DOUBLE);
+#else
+        int Size = sizeof(VECTOR);
+#endif
         PRINTDEBUG(dddif,3,(PFMT " ElementXferCopy():  e=" EID_FMTX
                             " EDGEVEC=" VINDEX_FMTX " size=%d\n",
                             me,EID_PRTX(pe),VINDEX_PRTX(vec),Size))
@@ -934,10 +934,10 @@ static void ElementXferCopy (DDD::DDDContext& context, DDD_OBJ obj, DDD_PROC pro
   /* copy element vector */
   if (ddd_ctrl(context).elemData)
   {
-    vec = EVECTOR(pe);
+    VECTOR *vec = EVECTOR(pe);
 
     if (vec != NULL) {
-      Size = sizeof(VECTOR)-sizeof(DOUBLE) + FMT_S_VEC_TP;
+      INT Size = sizeof(VECTOR)-sizeof(DOUBLE);
 
       PRINTDEBUG(dddif,2,(PFMT " ElementXferCopy(): e=" EID_FMTX
                           " ELEMVEC=" VINDEX_FMTX " size=%d\n",
@@ -948,14 +948,15 @@ static void ElementXferCopy (DDD::DDDContext& context, DDD_OBJ obj, DDD_PROC pro
   }
 
   /* copy sidevectors */
+#ifdef UG_DIM_3
   if (dddctrl.sideData)
   {
     for (i=0; i<SIDES_OF_ELEM(pe); i++)
     {
-      vec = SVECTOR(pe,i);
+      VECTOR *vec = SVECTOR(pe,i);
 
       if (vec != NULL) {
-        Size = sizeof(VECTOR)-sizeof(DOUBLE) + FMT_S_VEC_TP;
+        INT Size = sizeof(VECTOR);
 
         PRINTDEBUG(dddif,2,(PFMT " ElementXferCopy(): e=" EID_FMTX
                             " SIDEVEC=" VINDEX_FMTX " size=%d\n",
@@ -964,6 +965,7 @@ static void ElementXferCopy (DDD::DDDContext& context, DDD_OBJ obj, DDD_PROC pro
       }
     }
   }
+#endif
 }
 
 
@@ -1240,7 +1242,6 @@ static void ElemScatterB (DDD::DDDContext& context, DDD_OBJ obj, int cnt, DDD_TY
 
 static void ElementObjMkCons (DDD::DDDContext& context, DDD_OBJ obj, int newness)
 {
-  INT i,j;
   INT lostson         = 0;
   ELEMENT *pe                     = (ELEMENT *)obj;
   ELEMENT *succe          = SUCCE(pe);
@@ -1261,12 +1262,13 @@ static void ElementObjMkCons (DDD::DDDContext& context, DDD_OBJ obj, int newness
   /* correct nb relationships between ghostelements */
   if (EGHOST(pe))
   {
-    for (i=0; i<SIDES_OF_ELEM(pe); i++)
+    for (INT i = 0; i < SIDES_OF_ELEM(pe); i++)
     {
       NbElement = NBELEM(pe,i);
       if (NbElement!=NULL && EGHOST(NbElement))
       {
-        for (j=0; j<SIDES_OF_ELEM(NbElement); j++)
+        INT j = 0;
+        for (j = 0; j < SIDES_OF_ELEM(NbElement); j++)
           if (NBELEM(NbElement,j) == pe) break;
         /* no backptr reset nb pointer */
         if (j >= SIDES_OF_ELEM(NbElement)) SET_NBELEM(pe,i,NULL);
@@ -1277,11 +1279,13 @@ static void ElementObjMkCons (DDD::DDDContext& context, DDD_OBJ obj, int newness
   /* reconstruct pointer from vectors */
   if (ddd_ctrl(context).elemData) VOBJECT(EVECTOR(pe)) = (GEOM_OBJECT*)pe;
 
+#ifdef UG_DIM_3
   if (ddd_ctrl(context).sideData)
-    for (i=0; i<SIDES_OF_ELEM(pe); i++) {
+    for (INT i = 0; i < SIDES_OF_ELEM(pe); i++) {
       VOBJECT(SVECTOR(pe,i)) = (GEOM_OBJECT*)pe;
       SETVECTORSIDE(SVECTOR(pe,i), i);
     }
+#endif
 
   /*  if called with prio old=ghost and new=ghost,
           then you have eventually to unlink and link
@@ -1303,11 +1307,10 @@ static void ElementObjMkCons (DDD::DDDContext& context, DDD_OBJ obj, int newness
     else if (theFather != NULL)
     {
       ELEMENT *SonList[MAX_SONS];
-      int i;
 
       /* check whether NSONS of father must be incremented */
       if (GetAllSons(theFather,SonList)) ASSERT(0);
-      i = 0;
+      int i = 0;
       while (SonList[i] != NULL)
       {
         if (SonList[i] == pe) return;
@@ -1390,7 +1393,7 @@ static void ElementObjMkCons (DDD::DDDContext& context, DDD_OBJ obj, int newness
   /* update element count of edges for new created elements */
   if (newness == XFER_NEW)
     /* increment elem counter in edges */
-    for (i=0; i<EDGES_OF_ELEM(pe); i++)
+    for (INT i = 0; i < EDGES_OF_ELEM(pe); i++)
     {
       EDGE *theEdge;
       NODE *theNode0 = CORNER(pe,CORNER_OF_EDGE(pe,i,0));
@@ -1491,7 +1494,6 @@ static void ElementPriorityUpdate (DDD::DDDContext& context, DDD_OBJ obj, DDD_PR
   /* link element into list according to prio */
   {
     INT where   = PRIO2INDEX(new_);
-    ELEMENT *after;
 
     if (theFather != NULL)
     {
@@ -1509,7 +1511,7 @@ static void ElementPriorityUpdate (DDD::DDDContext& context, DDD_OBJ obj, DDD_PR
       }
 
       /* link elements with father */
-      after = SON(theFather,where);
+      ELEMENT *after = SON(theFather,where);
 
       PRINTDEBUG(dddif,2,(PFMT " ElementPriorityUpdate(): GRID_LINKX_ELEMENT "
                           "pe=" EID_FMTX " prio=%d after=%x\n",me,EID_PRTX(pe),new_,after))
