@@ -165,11 +165,7 @@ static Dune::FieldVector<DOUBLE, DIM> CenterOfMass (ELEMENT *e)
 
   const auto corners = CORNERS_OF_ELEM(e);
   for(int i=0; i<corners; i++)
-  {
-    auto* corner = CVECT(MYVERTEX(CORNER(e,i)));
-    for(int dimIdx=0; dimIdx < DIM; ++dimIdx)
-        center[dimIdx] += corner[dimIdx];
-  }
+    center +=  CVECT(MYVERTEX(CORNER(e,i)));
 
   center /= corners;
   return center;
@@ -226,7 +222,7 @@ static void InheritPartition (ELEMENT *e)
 
 void BalanceGridRCB (MULTIGRID *theMG, int level)
 {
-  GRID *theGrid = GRID_ON_LEVEL(theMG,level);
+  const GRID *theGrid = GRID_ON_LEVEL(theMG,level);
   DDD::DDDContext& context = theMG->dddContext();
   const PPIF::PPIFContext& ppifContext = theMG->ppifContext();
 
