@@ -194,9 +194,9 @@ static INT UpdateElementOverlap (DDD::DDDContext& context, ELEMENT *theElement)
       /* send son to all elements where theNeighbor is master, vghost or vhghost */
       if (0)
       {
-        for (auto&& [proc, prio] : DDD_InfoProcListRange(context, PARHDRE(theNeighbor), false))
+        for (auto&& [proc, currentPrio] : DDD_InfoProcListRange(context, PARHDRE(theNeighbor), false))
         {
-          if (!EHGHOSTPRIO(prio))
+          if (!EHGHOSTPRIO(currentPrio))
           {
             XFERECOPYX(context, theSon,proc,PrioHGhost,
                        (OBJT(theSon)==BEOBJ) ? BND_SIZE_TAG(TAG(theSon)) :
@@ -262,14 +262,11 @@ INT UpdateGridOverlap (GRID *theGrid)
 
 static INT UpdateMultiGridOverlap (MULTIGRID *theMG, INT FromLevel)
 {
-  INT l;
-  GRID    *theGrid;
-
   ddd_HandlerInit(theMG->dddContext(), HSET_REFINE);
 
-  for (l=FromLevel; l<TOPLEVEL(theMG); l++)
+  for (INT l = FromLevel; l < TOPLEVEL(theMG); l++)
   {
-    theGrid = GRID_ON_LEVEL(theMG,l);
+    GRID *theGrid = GRID_ON_LEVEL(theMG,l);
     UpdateGridOverlap(theGrid);
   }
 
@@ -567,7 +564,7 @@ INT ConnectVerticalOverlap (MULTIGRID *theMG)
          theElement!=NULL; theElement=SUCCE(theElement))
     {
       INT prio = EPRIO(theElement);
-      INT neflag = NO;
+      bool neflag = false;
       INT i;
 
       if (prio == PrioMaster) break;
@@ -611,7 +608,7 @@ INT ConnectVerticalOverlap (MULTIGRID *theMG)
                 /* Father found, hence exit loop. Otherwise multiple fixes lead to element list inconsistency
                    and endless element loop */
                 /* Achim 030506 */
-                neflag = YES;
+                neflag = true;
                 break;
               }
               else
@@ -625,7 +622,7 @@ INT ConnectVerticalOverlap (MULTIGRID *theMG)
                 /* Father found, hence exit loop. Otherwise multiple fixes lead to element list inconsistency
                    and endless element loop */
                 /* Achim 030506 */
-                neflag = YES;
+                neflag = true;
                 break;
               }
               SETNSONS(el,NSONS(el)+1);
@@ -634,7 +631,7 @@ INT ConnectVerticalOverlap (MULTIGRID *theMG)
           /* Father found, hence exit loop. Otherwise multiple fixes lead to element list inconsistency
              and endless element loop */
           /* Achim 030506 */
-          if (neflag == YES)
+          if (neflag == true)
             break;
         }
       }
@@ -648,10 +645,8 @@ static INT ConnectOverlapVerticalGrid (GRID *theGrid)
 {
   INT i,j,k,found,edgenode0,edgenode1;
   ELEMENT *theElement,*theSon,*SonList[MAX_SONS];
-  NODE    *theNode,*SonNode,*FatherNode,*EdgeNode0,*EdgeNode1;
-  EDGE    *theEdge,*FatherEdge;
   VERTEX  *theVertex;
-  DOUBLE  *songlobal,diff;
+  DOUBLE diff;
   DOUBLE_VECTOR global;
 
   for (theElement=PFIRSTELEMENT(theGrid); theElement!=NULL; theElement=SUCCE(theElement))
@@ -664,12 +659,13 @@ static INT ConnectOverlapVerticalGrid (GRID *theGrid)
       for (j=0; j<CORNERS_OF_ELEM(theSon); j++)
       {
         found = 0;
-        SonNode = CORNER(theSon,j);
+        NODE *SonNode = CORNER(theSon, j);
         switch(NTYPE(SonNode))
         {
         case CORNER_NODE :
-          FatherNode = (NODE *) NFATHER(SonNode);
-          if (FatherNode != NULL)
+        {
+          const NODE *FatherNode = (NODE *) NFATHER(SonNode);
+          if (FatherNode != nullptr)
           {
             assert(SONNODE(FatherNode) == SonNode);
             break;
@@ -677,7 +673,7 @@ static INT ConnectOverlapVerticalGrid (GRID *theGrid)
           assert(!MOVED(MYVERTEX(SonNode)));
           for (k=0; k<CORNERS_OF_ELEM(theElement); k++)
           {
-            theNode = CORNER(theElement,k);
+            NODE *theNode = CORNER(theElement,k);
             if (MYVERTEX(theNode) == MYVERTEX(SonNode))
             {
               assert(found == 0);
@@ -693,9 +689,11 @@ static INT ConnectOverlapVerticalGrid (GRID *theGrid)
             }
           }
           break;
+        }
         case MID_NODE :
-          FatherEdge = (EDGE *) NFATHER(SonNode);
-          if (FatherEdge != NULL)
+        {
+          const EDGE *FatherEdge = (EDGE *) NFATHER(SonNode);
+          if (FatherEdge != nullptr)
           {
             assert(MIDNODE(FatherEdge) == SonNode);
             break;
@@ -705,13 +703,13 @@ static INT ConnectOverlapVerticalGrid (GRID *theGrid)
           {
             edgenode0 = CORNER_OF_EDGE(theElement,k,0);
             edgenode1 = CORNER_OF_EDGE(theElement,k,1);
-            EdgeNode0 = CORNER(theElement,edgenode0);
-            EdgeNode1 = CORNER(theElement,edgenode1);
+            const NODE *EdgeNode0 = CORNER(theElement, edgenode0);
+            const NODE *EdgeNode1 = CORNER(theElement, edgenode1);
             assert(EdgeNode0!=NULL && EdgeNode1!=NULL);
 
-            theEdge = GetEdge(EdgeNode0,EdgeNode1);
-            assert(theEdge != NULL);
-            songlobal = CVECT(MYVERTEX(SonNode));
+            EDGE *theEdge = GetEdge(EdgeNode0, EdgeNode1);
+            assert(theEdge != nullptr);
+            const FieldVector<DOUBLE,DIM>& songlobal = CVECT(MYVERTEX(SonNode));
             V_DIM_LINCOMB(0.5, CVECT(MYVERTEX(EdgeNode0)),
                           0.5, CVECT(MYVERTEX(EdgeNode1)),global);
             V_DIM_EUKLIDNORM_OF_DIFF(songlobal,global,diff);
@@ -750,6 +748,7 @@ static INT ConnectOverlapVerticalGrid (GRID *theGrid)
             }
           }
           break;
+        }
         case SIDE_NODE :
         case CENTER_NODE :
           /* do nothing */
@@ -766,12 +765,9 @@ static INT ConnectOverlapVerticalGrid (GRID *theGrid)
 
 static INT ConnectOverlapVerticalMultiGrid (MULTIGRID *theMG)
 {
-  INT i;
-  GRID    *theGrid;
-
-  for (i=0; i<=TOPLEVEL(theMG); i++)
+  for (INT i = 0; i <= TOPLEVEL(theMG); i++)
   {
-    theGrid = GRID_ON_LEVEL(theMG,i);
+    GRID *theGrid = GRID_ON_LEVEL(theMG,i);
     if (ConnectOverlapVerticalGrid(theGrid)) return(GM_ERROR);
   }
   return(GM_OK);
