@@ -48,7 +48,6 @@
 #include <dune/uggrid/gm/ugm.h>
 #include <dune/uggrid/low/debug.h>
 #include <dune/uggrid/low/namespace.h>
-#include <dune/uggrid/low/ugtime.h>
 #include <dune/uggrid/low/ugtypes.h>
 
 /* UG namespaces: */
@@ -350,7 +349,6 @@ static int Gather_VHGhostCmd (DDD::DDDContext&, DDD_OBJ obj, void *data, DDD_PRO
 {
   ELEMENT *theElement = (ELEMENT *)obj;
   // ELEMENT *theFather      = EFATHER(theElement);
-  ELEMENT *theNeighbor;
   INT j;
 
   if (PARTITION(theElement) != proc)
@@ -359,7 +357,7 @@ static int Gather_VHGhostCmd (DDD::DDDContext&, DDD_OBJ obj, void *data, DDD_PRO
 
     for(j=0; j<SIDES_OF_ELEM(theElement); j++)
     {
-      theNeighbor = NBELEM(theElement,j);
+      ELEMENT *theNeighbor = NBELEM(theElement,j);
 
       if (theNeighbor != NULL)
       {
@@ -469,84 +467,6 @@ static int ComputeGhostCmds (MULTIGRID *theMG)
   return(0);
 }
 
-/****************************************************************************/
-
-#ifdef __OVERLAP2__
-static int XferNodesForOverlap2 (GRID *theGrid)
-{
-  auto& dddctrl = ddd_ctrl(theGrid->dddContext());
-  ELEMENT *theElement;
-  NODE    *theNode;
-  INT i,part;
-  MATRIX  *mat,*mat2;
-  VECTOR  *vec,*dest;
-  INT Size;
-
-  for(theElement=FIRSTELEMENT(theGrid); theElement!=NULL; theElement=SUCCE(theElement))
-  {
-    /* ensuring the overlap is for all elements necessary, because even for
-       elements remaining on this processor their overlap may have been deleted
-       some lines above */
-
-    part = PARTITION(theElement);
-
-    /* traverse all corner vectors */
-    for(i=0; i<CORNERS_OF_ELEM(theElement); i++)
-    {
-      theNode = CORNER(theElement,i);
-      vec = NVECTOR(theNode);
-
-      PRINTDEBUG(dddif,2,(PFMT " XferGridWithOverlap():  e=" EID_FMTX
-                          " Xfer n=" ID_FMTX " i=%d\n",
-                          me,EID_PRTX(theElement),ID_PRTX(theNode),i))
-
-      /* for master vectors all matrix neighbors within link depth 2
-          must be copied too; the vec itself is automatically copied
-              by the node-copy-handler */
-      for(mat=MNEXT(VSTART(vec)); mat!=NULL; mat=MNEXT(mat))
-      {
-        dest = MDEST(mat);
-        if (dest != NULL)
-        {
-          Size = sizeof(VECTOR)-sizeof(DOUBLE)
-                 +FMT_S_VEC_TP(MGFORMAT(dddctrl.currMG),VTYPE(dest));
-
-          PRINTDEBUG(dddif,2,(PFMT " XferGridWithOverlap(): n=" ID_FMTX
-                              " Xfer NODEVEC=" VINDEX_FMTX " 1. NBvec  "
-                              VINDEX_FMTX " size=%d\n",
-                              me,ID_PRTX(theNode),VINDEX_PRTX(vec),VINDEX_PRTX(dest),Size))
-          /* TODO: only vectors are necessary; only for debugging: send also the corresponding node to have geometric information */
-          SETNO_DELETE_OVERLAP2((NODE*)VOBJECT(dest),1);
-          DDD_XferCopyObj(PARHDR((NODE*)VOBJECT(dest)), part, PrioHGhost);
-          /*DDD_XferCopyObjX(PARHDR(dest), part, PrioHGhost, Size);*/
-        }
-
-        for(mat2=MNEXT(VSTART(dest)); mat2!=NULL; mat2=MNEXT(mat2))
-        {
-          dest = MDEST(mat2);
-          if (dest != NULL)
-          {
-            Size = sizeof(VECTOR)-sizeof(DOUBLE)
-                   +FMT_S_VEC_TP(MGFORMAT(dddctrl.currMG),VTYPE(dest));
-
-            PRINTDEBUG(dddif,2,(PFMT " XferGridWithOverlap(): n=" ID_FMTX
-                                " Xfer NODEVEC=" VINDEX_FMTX " 2. NBvec  "
-                                VINDEX_FMTX " size=%d\n",
-                                me,ID_PRTX(theNode),VINDEX_PRTX(vec),VINDEX_PRTX(dest),Size))
-
-            /* TODO: only vectors are necessary; only for debugging: send also the corresponding node to have geometric information */
-            SETNO_DELETE_OVERLAP2((NODE*)VOBJECT(dest),1);
-            DDD_XferCopyObj(PARHDR((NODE*)VOBJECT(dest)), part, PrioHGhost);
-            /*DDD_XferCopyObjX(PARHDR(dest), part, PrioHGhost, Size);*/
-          }
-        }
-      }
-    }
-  }
-  return (0);
-}
-#endif
-
 /****************************************************************************/
 /*
    XferGridWithOverlap - send elements to other procs, keep overlapping region of one element, maintain correct priorities at interfaces.
@@ -680,10 +600,6 @@ static int XferGridWithOverlap (GRID *theGrid)
     }
   }
 
-#ifdef __OVERLAP2__
-  if (XferNodesForOverlap2(theGrid)) assert(0);
-#endif
-
   return(migrated);
 }
 
@@ -755,20 +671,6 @@ int NS_DIM_PREFIX TransferGridFromLevel (MULTIGRID *theMG, INT level)
   DOUBLE trans_begin, trans_end, cons_end;
 #endif
 
-#ifdef __OVERLAP2__
-  NODE *node;
-
-  Set_Current_BVP(theMG->theBVP);
-
-  ASSERT(AllocateControlEntry(NODE_CW,NO_DELETE_OVERLAP2_LEN,&ce_NO_DELETE_OVERLAP2) == GM_OK);
-  for (INT g=0; g<=TOPLEVEL(theMG); g++)
-  {
-    GRID *theGrid = GRID_ON_LEVEL(theMG,g);
-    for( node=PFIRSTNODE(theGrid); node!= NULL; node=SUCCN(node) )
-      SETNO_DELETE_OVERLAP2(node,0);                    /* reset flag */
-  }
-#endif
-
 #ifdef STAT_OUT
   trans_begin = CURRENT_TIME;
 #endif
@@ -807,17 +709,6 @@ int NS_DIM_PREFIX TransferGridFromLevel (MULTIGRID *theMG, INT level)
   trans_end = CURRENT_TIME;
 #endif
 
-#ifdef __OVERLAP2__
-  for (INT g=0; g<=TOPLEVEL(theMG); g++)
-  {
-    GRID *theGrid = GRID_ON_LEVEL(theMG,g);
-    for( node=PFIRSTNODE(theGrid); node!= NULL; node=SUCCN(node) )
-      SETNO_DELETE_OVERLAP2(node,0);                    /* reset flag */
-  }
-  FreeControlEntry(ce_NO_DELETE_OVERLAP2);
-  ce_NO_DELETE_OVERLAP2 = -1;           /* don't use further NO_DELETE_OVERLAP2 */
-#endif
-
   /* set priorities of border nodes */
   /* TODO this is an extra communication. eventually integrate this
               with grid distribution phase. */
